SystemOrganization addCategory: #'DAO-TP-Changes'!

!DateAndTime class methodsFor: '*DAO-TP-Changes' stamp: 'Maxi 12/06/2013 13:13'!
year: year day: dayOfYear
	"Synopsis
	Answer a <DateAndTime> which is the second second of the minute minute of the hour hour of
	the day dayOfYear of the year year of the astronomical Gregorian calendar in local time.
	Definition: <DateAndTime factory>
	Answer the least <DateAndTime> which is the second second of the minute minute of the hour
	hour of the day dayOfYear of the year year of the astronomical Gregorian calendar in the local
	time specified by the implementation. The second must be a <number> greater than or equal to 0
	and strictly less than 60. The minute must be an <integer> between 0 and 59 inclusive. The hour
	must be an <integer> between 0 and 23 inclusive. The day must be an <integer> between 1 and
	366 inclusive. An implementation may not impose any limits on the year other than those imposed
	on <integer> constants.
	It is possible that the time specified does not exist in the local time specified by the implementation.
	If there is a time change such that the local time is set forward and the time specified is in the
	interregnum, then that time does not exist in the local time. For example if at 02:00 in California on
	April 26, 1997 there is a time change that sets local time forward one hour, then the local time
	02:30 in California does not exist. Conversely if there is a time change that sets the local time back
	there are times which are ambiguous. For example if instead of setting the local time forward from
	02:00 to 03:00 it is set back to 01:00 the the local time 01:30 in California is ambiguious. The result
	is the least <DateAndTime> that conforms to the given parameters.
	It is worth noting that the year 1 B.C. is year 0 in the astronomical Gregorian calendar. Similarly the
	year 2 B.C. is year -1 in the astronomical Gregorian calendar and so on. The year 1 A.D. is year 1
	in the astronomical Gregorian calendar.
	Parameters
	year <integer> unspecified
	dayOfYear <integer> unspecified
	hour <integer> unspecified
	minute <integer> unspecified
	second <number> unspecified
	Return Values
	<DateAndTime> new
	Errors
	month is not between 1 and 12 inclusive.
	dayOfYear greater than the number of days in the year year of the astronomical Gregorian
	calendar.
	hour is not between 0 and 23 inclusive.
	minute is not between 0 and 59 inclusive.
	second is not greater than or equal to 0 and strictly less than 60.
	the time specified does not exist."

	^self 
		year: year 
		day: dayOfYear 
		hour: 0 
		minute: 0 
		second: 0.
! !

Error subclass: #UnidadDeTrabajoException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

WAComponent subclass: #ChangesSeaside
	instanceVariableNames: ''
	classVariableNames: 'Interfaz'
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ChangesSeaside class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/27/2013 01:02'!
description
	^ 'A very simple (simple?) Seaside application'! !

!ChangesSeaside class methodsFor: 'as yet unclassified' stamp: 'Maxii 12/7/2013 21:21'!
handlerName
	^ 'tp2'! !

!ChangesSeaside class methodsFor: 'as yet unclassified' stamp: 'Maxii 12/7/2013 21:20'!
initializeWith: unaInterfazDeEntradaWeb


	WAAdmin register: self asApplicationAt: self handlerName.
	
	Interfaz := unaInterfazDeEntradaWeb.

! !

!ChangesSeaside class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 17:55'!
interfaz
	^Interfaz! !

!ChangesSeaside class methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 12:38'!
reinicializarInterfaz
		| |
	
	Interfaz := InterfazDeEntradaWeb new: Interfaz sistemaDeCambios.
! !

!ChangesSeaside methodsFor: 'as yet unclassified' stamp: 'Maxii 10/28/2013 23:36'!
initialize
	super initialize.
! !

!ChangesSeaside methodsFor: 'as yet unclassified' stamp: 'Maxii 10/28/2013 23:36'!
renderContentOn: html
	Interfaz dibujarEn: html! !

!ChangesSeaside methodsFor: 'as yet unclassified' stamp: 'Maxii 10/24/2013 23:10'!
states
	^ Array with: self! !

TestCase subclass: #ChangesTest
	instanceVariableNames: 'diccionarioDeAcciones nombreDelAutor fechaYHoraTest registroDePruebaC1 registroDePruebaC2 registroDePruebaC3 registroDePruebaC4 registroDePruebaC5 registroDePruebaC6'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

ChangesTest subclass: #Blah
	instanceVariableNames: 'uno dos'
	classVariableNames: 'Cuatro Tres'
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ChangesTest class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 23:06'!
mensajeTest
	^self.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 22:42'!
algunaUnidadDeTrabajo
	^UnidadDeTrabajoInicial  new.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 23:05'!
autorTest
	^self.! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
class: aClass recategorizedFrom: oldCategory to: newCategory
	(diccionarioDeAcciones at: ClassRecategorized) value: (ClassRecategorized class: aClass recategorizedFrom: oldCategory to: newCategory).
! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
classAdded: aClass inCategory: aCategoryName 
	(diccionarioDeAcciones at: ClassAdded) value: (ClassAdded class: aClass category: aCategoryName).! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
classCategoryAdded: unNombreDeCategoria 
	(diccionarioDeAcciones at: CategoryAdded) value: (CategoryAdded categoryName: unNombreDeCategoria).! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
classCategoryRemoved: unNombreDeCategoria 
	(diccionarioDeAcciones at: CategoryRemoved) value: (CategoryRemoved categoryName: unNombreDeCategoria).! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
classCategoryRenamedFrom: anOldClassCategoryName to: aNewClassCategoryName
	(diccionarioDeAcciones at: CategoryRenamed ) value: (CategoryRenamed classCategoryRenamedFrom: anOldClassCategoryName to: aNewClassCategoryName).! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
classDefinitionChangedFrom: aBlahClass to: aBlahClass2 
	(diccionarioDeAcciones at: ClassModifiedClassDefinition) value:  (ClassModifiedClassDefinition classDefinitionChangedFrom: aBlahClass to: aBlahClass2)! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
classRemoved: aClass fromCategory: aCategoryName
	( diccionarioDeAcciones at: ClassRemoved ) value: (ClassRemoved class: aClass category: aCategoryName).! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 21:03'!
classReorganized: aClass 
	(diccionarioDeAcciones at: ClassReorganized) value: (ClassReorganized class: aClass).! !

!ChangesTest methodsFor: 'author' stamp: 'Maxii 10/21/2013 12:18'!
fullName
	nombreDelAutor isNil ifTrue: [ nombreDelAutor := 'Sebas' ].
	^nombreDelAutor.! !

!ChangesTest methodsFor: 'author' stamp: 'SebastianGarbi 10/13/2013 23:05'!
fullName: unNombreDelAutor 
	nombreDelAutor := unNombreDelAutor.! !

!ChangesTest methodsFor: 'initialize-release' stamp: 'SebastianGarbi 10/19/2013 22:25'!
initialize 
	diccionarioDeAcciones := Dictionary new.
	self fullName: 'Nombre'.
	self setear: DateAndTime now.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 18:47'!
interfazDeEntradaInicializada
	| unAutor unReloj unSistemaDeCambios |
	unReloj := self relojTest.
	unAutor := self autorTest.
	unSistemaDeCambios := SistemaDeCambios new.
	unAutor fullName: 'Seba'.
	unReloj setear: DateAndTime now.
	^InterfazDeEntradaDelSistemaDeCambios newWith: unSistemaDeCambios andThisAuthor: unAutor andThisClock: unReloj! !

!ChangesTest methodsFor: 'tests' stamp: 'SebastianGarbi 10/20/2013 19:15'!
mensajeTestInstancia
	^true.! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
methodAdded: aMethod selector: aSymbol inProtocol: aCategoryName class: aClass requestor: requestor
	(diccionarioDeAcciones at: MethodAdded ) value: (MethodAdded method: aMethod selector: aSymbol protocol: aCategoryName class: aClass requestor: requestor).
	
	
! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
methodChangedFrom: oldMethod to: newMethod selector: aSelector inClass: aClass oldProtocol: oldProtocol newProtocol: newProtocol requestor: anUndefinedObject 
	(diccionarioDeAcciones at: MethodModified ) value: (
		MethodModified	methodChangedFrom: oldMethod
							to: newMethod
							selector: aSelector 
							inClass: aClass
							oldProtocol: oldProtocol
							newProtocol: newProtocol
							requestor: anUndefinedObject
						).! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:05'!
methodRemoved: aMethod selector: aSymbol inProtocol: protocol class: aClass origin: anOrigin
	(diccionarioDeAcciones at: MethodRemoved ) value: (MethodRemoved methodRemoved: aMethod selector: aSymbol protocol: protocol class: aClass origin: anOrigin).! !

!ChangesTest methodsFor: 'clock' stamp: 'Maxii 10/19/2013 18:25'!
now
	fechaYHoraTest isNil ifTrue: [ fechaYHoraTest := DateAndTime now ].
	^fechaYHoraTest.! !

!ChangesTest methodsFor: 'convenience' stamp: 'SebastianGarbi 10/13/2013 23:06'!
on: unTipoDeEvento do: aBlockClosure 
	
	diccionarioDeAcciones at: unTipoDeEvento put: aBlockClosure.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'Maxii 10/21/2013 12:16'!
registroClassCreatedC1
	"Este mensaje nos devuelve un registro para que guarde el sistema de cambios"
	| cambioDePrueba fechaYHoraParaElCambio01 |
	registroDePruebaC1 ifNil: [ 
		cambioDePrueba := ClassCreatedChange class: 'C1' category: 'nombre de la categoria' superclass: self class name.
		fechaYHoraParaElCambio01 := DateAndTime year: 2013 day: 1.
		registroDePruebaC1 := RegistroDeCambio newWithThischange: cambioDePrueba andThisAuthor: self autorTest fullName atThisTime: fechaYHoraParaElCambio01. 
	]. 
	
	^registroDePruebaC1.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'Maxii 10/21/2013 12:17'!
registroClassCreatedC2
	"Este mensaje nos devuelve un registro para que guarde el sistema de cambios"
	| cambioDePrueba fechaYHoraParaElCambio02 |
	registroDePruebaC2 ifNil: [ 
		cambioDePrueba := ClassCreatedChange class: 'C2' category: 'nombre de la categoria' superclass: self class name.
		fechaYHoraParaElCambio02 := DateAndTime year: 2013 day: 2.
		registroDePruebaC2 := RegistroDeCambio newWithThischange: cambioDePrueba andThisAuthor: self autorTest fullName atThisTime: fechaYHoraParaElCambio02
	]. 
	
	^registroDePruebaC2.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'Maxii 10/21/2013 12:17'!
registroClassCreatedC3
	"Este mensaje nos devuelve un registro para que guarde el sistema de cambios"
	| cambioDePrueba fechaYHoraParaElCambio03 |
	registroDePruebaC3 ifNil: [ 
		cambioDePrueba := ClassCreatedChange class: 'C3' category: 'nombre de la categoria' superclass: self class name.
		fechaYHoraParaElCambio03 := DateAndTime year: 2013 day: 3.
		registroDePruebaC3 := RegistroDeCambio newWithThischange: cambioDePrueba andThisAuthor: self autorTest fullName atThisTime: fechaYHoraParaElCambio03. 
	]. 
	
	^registroDePruebaC3.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'Maxii 10/21/2013 12:17'!
registroClassCreatedC4
	"Este mensaje nos devuelve un registro para que guarde el sistema de cambios"
	| cambioDePrueba fechaYHoraParaElCambio |
	registroDePruebaC4 ifNil: [ 
		cambioDePrueba := ClassCreatedChange class: 'C4' category: 'nombre de la categoria' superclass: self class name.
		fechaYHoraParaElCambio := DateAndTime year: 2013 day: 4.
		registroDePruebaC4 := RegistroDeCambio newWithThischange: cambioDePrueba andThisAuthor: self autorTest fullName atThisTime: fechaYHoraParaElCambio. 
	]. 
	
	^registroDePruebaC4.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'Maxii 10/21/2013 12:17'!
registroClassCreatedC5
	"Este mensaje nos devuelve un registro para que guarde el sistema de cambios"
	| cambioDePrueba fechaYHoraParaElCambio |
	registroDePruebaC5 ifNil: [ 
		cambioDePrueba := ClassCreatedChange class: 'C5' category: 'nombre de la categoria' superclass: self class name.
		fechaYHoraParaElCambio := DateAndTime year: 2013 day: 5.
		registroDePruebaC5 := RegistroDeCambio newWithThischange: cambioDePrueba andThisAuthor: self autorTest fullName atThisTime: fechaYHoraParaElCambio. 
	]. 
	
	^registroDePruebaC5.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'Maxii 10/21/2013 12:17'!
registroClassCreatedC6
	"Este mensaje nos devuelve un registro para que guarde el sistema de cambios"
	| cambioDePrueba fechaYHoraParaElCambio |
	registroDePruebaC6 ifNil: [ 
		cambioDePrueba := ClassCreatedChange class: 'C6' category: 'nombre de la categoria' superclass: self class name.
		fechaYHoraParaElCambio := DateAndTime year: 2013 day: 6.
		registroDePruebaC6 := RegistroDeCambio newWithThischange: cambioDePrueba andThisAuthor: self autorTest fullName atThisTime: fechaYHoraParaElCambio. 
	]. 
	
	^registroDePruebaC6.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 23:06'!
registroClassMethodCreatedC1
	| cambioDePrueba |
	registroDePruebaC1 ifNil: [ 
		cambioDePrueba := ClassMethodCreatedChange classAffected: 'ChangesTest' methodName: 'now' methodCategory: 'as yet unclassified' sourceCode: '^self'.
		registroDePruebaC1 := RegistroDeCambio newWithThischange: cambioDePrueba andThisAuthor: 'Sebas' atThisTime: self now . 
	]. 
	
	^registroDePruebaC1.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 23:06'!
registroInstanceMethodCreatedC1
	| cambioDePrueba |
	registroDePruebaC1 ifNil: [ 
		cambioDePrueba := InstanceMethodCreatedChange classAffected: 'ChangesTest' methodName: 'now' methodCategory: 'as yet unclassified' sourceCode: '^self'.
		registroDePruebaC1 := RegistroDeCambio newWithThischange: cambioDePrueba andThisAuthor: 'Sebas' atThisTime: self now . 
	]. 
	
	^registroDePruebaC1.! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 23:06'!
relojTest
	^self.! !

!ChangesTest methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 23:06'!
selector: aSelector recategorizedFrom: aNewProtocol to: anOldProtocol inClass: aClass 
	(diccionarioDeAcciones at: MethodRecategorized) value: (MethodRecategorized method: (aClass compiledMethodAt: aSelector ifAbsent: [nil]) selector: aSelector class: aClass newProtocol: anOldProtocol oldProtocol: aNewProtocol  ).! !

!ChangesTest methodsFor: 'clock' stamp: 'SebastianGarbi 10/13/2013 23:06'!
setear: aDateAndTime 
	fechaYHoraTest := aDateAndTime.! !

!ChangesTest methodsFor: 'tests' stamp: 'SebastianGarbi 11/3/2013 20:30'!
test01
	| unSistema tdd |
	unSistema := SistemaDeCambios new.
	tdd := TDDVsTestingVisitor for: unSistema.
	tdd value.
	self assert:(true).	
	"ZnZincServerAdaptor startOn: 8080"
"unSistemaDeCambios := SistemaDeCambios new."
"ChangesSeaside setearSistemaDeCambios: unSistemaDeCambios."
"unaInterfazDeEntrada := InterfazDeEntradaDelSistemaDeCambios newWith: unSistemaDeCambios andThisAuthor: Author andThisClock: DateAndTime."
"unaInterfazDeAnuncios := InterfazParaAnuncios newWith:  SystemAnnouncer uniqueInstance and: unaInterfazDeEntrada "
"SystemAnnouncer uniqueInstance unsubscribe: unaInterfazDeAnuncios."! !

!ChangesTest methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 23:06'!
unSystemAnnouncer
	^self.! !

ChangesTest subclass: #ChangesTestClaseEstaticaDePrueba
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ChangesTestClaseEstaticaDePrueba methodsFor: 'unNombreDeProtocolo' stamp: 'Maxii 10/31/2013 18:54'!
dsa! !

ChangesTest subclass: #InerfazDeEntradaTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:59'!
test01ClassCategoryCreated

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classCategoryCreated: #'DAO-TP-Changes'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
"		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
"		self assert: (unRegistroDeCambio cambio categoryName = #'DAO-TP-Changes').
		self assert: (unRegistroDeCambio cambio evento = ClassCategoryCreatedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:59'!
test02ClassCategoryRemoved

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classCategoryRemoved: #'DAO-TP-Changes'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
"		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now)."
		self assert: (unRegistroDeCambio cambio categoryName = #'DAO-TP-Changes').
		self assert:(unRegistroDeCambio cambio evento = ClassCategoryRemovedChange evento)
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 22:14'!
test03ClassCategoryRenamed

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classCategoryRenamedFrom: #'DAO-TP-Changes' to: #'DAO-TP-Changes2'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
"		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now)."
		self assert: (unRegistroDeCambio cambio oldCategoryName  = #'DAO-TP-Changes').
		self assert: (unRegistroDeCambio cambio newCategoryName  = #'DAO-TP-Changes2').
		self assert: (unRegistroDeCambio cambio evento = ClassCategoryRenamedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 20:22'!
test04ClassCreated

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classCreated: #'ChangesTest' inCategory: #'DAO-TP-Changes' superclass: #Object.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
"		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now)."
		self assert: (unRegistroDeCambio cambio classCreated = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio classCategory = #'DAO-TP-Changes').
		self assert: (unRegistroDeCambio cambio superclass = #'Object').
		self assert: (unRegistroDeCambio cambio evento = ClassCreatedChange evento)
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:59'!
test05ClassRemoved

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classRemoved: #'ChangesTest' fromCategory: #'DAO-TP-Changes'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
"		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now)."
		self assert: (unRegistroDeCambio cambio classRemoved = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio classCategory = #'DAO-TP-Changes').
		self assert: (unRegistroDeCambio cambio evento = ClassRemovedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:59'!
test06ClassRecategorized

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classRecategorized: #'ChangesTest' fromCategory: #'DAO-TP-Changes' toCategory: #'DAO-TP-Changes2'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
"		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now)."
		self assert: (unRegistroDeCambio cambio classRecategorized = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio oldCategory = #'DAO-TP-Changes').
		self assert: (unRegistroDeCambio cambio newCategory = #'DAO-TP-Changes2').
		self assert: (unRegistroDeCambio cambio evento = ClassRecategorizedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:59'!
test07SuperClassChanged

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada superclassChangedOn: #'ChangesTest' from: #'Object' to: #'TestCase'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
"		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now)."
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio oldSuperclass = #'Object').
		self assert: (unRegistroDeCambio cambio newSuperclass = #'TestCase').
		self assert: (unRegistroDeCambio cambio evento = SuperclassChangedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test13InstanceVariableCreated

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada instanceVariableCreatedOn: #'ChangesTest' named: #'hola'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio variableName = #'hola').
		self assert: (unRegistroDeCambio cambio evento = InstanceVariableCreatedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test14InstanceVariableRemoved

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada instanceVariableRemovedFrom: #'ChangesTest' named: #'hola'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio variableName = #'hola').
		self assert: (unRegistroDeCambio cambio evento = InstanceVariableRemovedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test15ClassInstanceVariableCreated

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classInstanceVariableCreatedOn: #'ChangesTest' named: #'hola'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio variableName = #'hola').
		self assert: (unRegistroDeCambio cambio evento = ClassInstanceVariableCreatedChange  evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test16ClassInstanceVariableRemoved

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classInstanceVariableRemovedFrom: #'ChangesTest' named: #'hola'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio variableName = #'hola').
		self assert: (unRegistroDeCambio cambio evento = ClassInstanceVariableRemovedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test17ClassVariableCreated

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classVariableCreatedOn: #'ChangesTest' named: #'hola'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio variableName = #'hola').
		self assert: (unRegistroDeCambio cambio evento = ClassVariableCreatedChange  evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test18ClassVariableRemoved

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classVariableRemovedFrom: #'ChangesTest' named: #'hola'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio variableName = #'hola').
		self assert: (unRegistroDeCambio cambio evento = ClassVariableRemovedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test21ClassMethodCreated

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classMethod: #'funcion' createdOn: #'ChangesTest' inCategory: #'as yet unclassified' withCode: #'^147'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio methodName = #'funcion').
		self assert: (unRegistroDeCambio cambio methodCategory = #'as yet unclassified').
		self assert: (unRegistroDeCambio cambio sourceCode = #'^147').
		self assert: (unRegistroDeCambio cambio evento = ClassMethodCreatedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test22ClassMethodRemoved

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classMethod: #'funcion' removedFrom: #'ChangesTest' inCategory: #'as yet unclassified' withCode: #'^147'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio methodName = #'funcion').
		self assert: (unRegistroDeCambio cambio methodCategory = #'as yet unclassified').
		self assert: (unRegistroDeCambio cambio sourceCode = #'^147').
		self assert: (unRegistroDeCambio cambio evento = ClassMethodRemovedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test23ClassMethodRecategorized

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classMethod: #'funcion' onClass: #'ChangesTest' recategorizedFrom: #'as yet unclassified' to: #'as yet unclassified2'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio methodName = #'funcion').
		self assert: (unRegistroDeCambio cambio oldMethodCategory = #'as yet unclassified').
		self assert: (unRegistroDeCambio cambio newMethodCategory = #'as yet unclassified2').
		self assert: (unRegistroDeCambio cambio evento = ClassMethodRecategorizedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/20/2013 19:48'!
test24ClassMethodChanged

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada classMethodChanged: #'funcion' onClass: #'ChangesTest' oldSourceCode: '^self' newSourceCode: '^444'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio methodName = #'funcion').
		self assert: (unRegistroDeCambio cambio oldSourceCode = '^self').
		self assert: (unRegistroDeCambio cambio newSourceCode = '^444').
		
		self assert: (unRegistroDeCambio cambio evento = ClassMethodChangedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test25InstanceMethodCreated

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada instanceMethod: #'funcion' createdOn: #'ChangesTest' inCategory: #'as yet unclassified' withCode: #'^147'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio methodName = #'funcion').
		self assert: (unRegistroDeCambio cambio methodCategory = #'as yet unclassified').
		self assert: (unRegistroDeCambio cambio sourceCode = #'^147').
		self assert: (unRegistroDeCambio cambio evento = InstanceMethodCreatedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test26InstanceMethodRemoved

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada instanceMethod: #'funcion' removedFrom: #'ChangesTest' inCategory: #'as yet unclassified' withCode: #'^147'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio methodName = #'funcion').
		self assert: (unRegistroDeCambio cambio methodCategory = #'as yet unclassified').
		self assert: (unRegistroDeCambio cambio sourceCode = #'^147').
		self assert: (unRegistroDeCambio cambio evento = InstanceMethodRemovedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test27InstanceMethodRecategorized

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada instanceMethod: #'funcion' onClass: #'ChangesTest' recategorizedFrom: #'as yet unclassified' to: #'as yet unclassified2'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio methodName = #'funcion').
		self assert: (unRegistroDeCambio cambio oldMethodCategory = #'as yet unclassified').
		self assert: (unRegistroDeCambio cambio newMethodCategory = #'as yet unclassified2').
		self assert: (unRegistroDeCambio cambio evento = InstanceMethodRecategorizedChange evento).
		]! !

!InerfazDeEntradaTest methodsFor: '05InterfazDeEntrada' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test28InstanceMethodChanged

	| unSistemaDeCambios  unaInterfaceDeEventosDeEntrada |

	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaInterfaceDeEventosDeEntrada instanceMethodChanged: #'funcion' onClass: #'ChangesTest' oldSourceCode: '^self' newSourceCode: '^444'.
	
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = self relojTest now).
		self assert: (unRegistroDeCambio cambio classAffected = #'ChangesTest').
		self assert: (unRegistroDeCambio cambio methodName = #'funcion').
		self assert: (unRegistroDeCambio cambio oldSourceCode = '^self').
		self assert: (unRegistroDeCambio cambio newSourceCode = '^444').
		self assert: (unRegistroDeCambio cambio evento = InstanceMethodChangedChange evento).
		]! !

ChangesTest subclass: #InerfazDeEntradaWebTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InerfazDeEntradaWebTest methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 12:53'!
test710LaInterfazDeEntradaWebPuedeObtenerLosCambiosAgrupadosPorElemento

	| unSistemaDeCambios unaInterfazDeEntradaWeb cambiosAgrupadosPorElementoDeUnGrupo resultadoEsperado primerGrupo |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC4.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC5.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC6.

	unaInterfazDeEntradaWeb := InterfazDeEntradaWeb new: unSistemaDeCambios.
	
	unaInterfazDeEntradaWeb agregarOQuitarUDT: 0 ok: false.
	unaInterfazDeEntradaWeb agregarOQuitarUDT: 1 ok: true.
	unaInterfazDeEntradaWeb agregarOQuitarUDT: 2 ok: true.
	
	cambiosAgrupadosPorElementoDeUnGrupo := unaInterfazDeEntradaWeb cambiosCategorizadosPorElementoDeLasUnidadesSeleccionadas.
	
	primerGrupo := OrderedCollection new.
	primerGrupo add: self registroClassCreatedC2.
	primerGrupo add: self registroClassCreatedC3.
	
	resultadoEsperado := Dictionary new. 
	resultadoEsperado at: 'Clase' put: Dictionary new.
	(resultadoEsperado at: 'Clase') at:'ClassCreated' put: primerGrupo.
	
	self assert: cambiosAgrupadosPorElementoDeUnGrupo = resultadoEsperado.
! !

!InerfazDeEntradaWebTest methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 16:52'!
test751LaInterfazDeEntradaWebPuedeGenerarUnModeloADibujarSinLaUnidadActiva

	| unSistemaDeCambios unaInterfazDeEntradaWeb |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC4.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC5.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC6.

	unaInterfazDeEntradaWeb := InterfazDeEntradaWeb new: unSistemaDeCambios.
	
	unaInterfazDeEntradaWeb resetModelo.
	unaInterfazDeEntradaWeb agregarOQuitarUDT: 1 ok: true.
	unaInterfazDeEntradaWeb agregarOQuitarUDT: 0 ok: false.
	unaInterfazDeEntradaWeb agregarOQuitarUDTActiva: false.
	
	self assert: (unaInterfazDeEntradaWeb modeloADibujar unidadesCerradasAUsar includes: 1).
	self assert: unaInterfazDeEntradaWeb modeloADibujar unidadesCerradasAUsar size = 1.
	self deny: unaInterfazDeEntradaWeb modeloADibujar usarUnidadActiva.
! !

!InerfazDeEntradaWebTest methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 16:52'!
test752LaInterfazDeEntradaWebPuedeGenerarUnModeloADibujarSinLaUnidadActivaYDosUnidadesCerradas

	| unSistemaDeCambios unaInterfazDeEntradaWeb |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC4.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC5.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC6.

	unaInterfazDeEntradaWeb := InterfazDeEntradaWeb new: unSistemaDeCambios.
	
	unaInterfazDeEntradaWeb resetModelo.
	unaInterfazDeEntradaWeb agregarOQuitarUDT: 1 ok: true.
	unaInterfazDeEntradaWeb agregarOQuitarUDT: 2 ok: true.
	unaInterfazDeEntradaWeb armarModeloQuitandoUnidadActiva.
	
	self assert: (unaInterfazDeEntradaWeb modeloADibujar unidadesCerradasAUsar includes: 1).
	self assert: (unaInterfazDeEntradaWeb modeloADibujar unidadesCerradasAUsar includes: 2).
	self assert: unaInterfazDeEntradaWeb modeloADibujar unidadesCerradasAUsar size = 2.
	self deny: unaInterfazDeEntradaWeb modeloADibujar usarUnidadActiva.
! !

!InerfazDeEntradaWebTest methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 17:57'!
test753LaInterfazDeEntradaWebNoPuedeGenerarUnModeloADibujarConUnIdInvalido

	| unSistemaDeCambios unaInterfazDeEntradaWeb |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC4.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC5.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC6.
	
	unaInterfazDeEntradaWeb := InterfazDeEntradaWeb new: unSistemaDeCambios.
	
	self 	should: [ unaInterfazDeEntradaWeb agregarOQuitarUDT: 1000000 ok: true ] 
			raise: Error 
			withExceptionDo: [ :unError | self assert: (unError messageText = 'El Id no corresponde a una unidad de trabajo.') ] .
			
	self deny: (unaInterfazDeEntradaWeb modeloADibujar unidadesCerradasAUsar includes: 1000000).
! !

!InerfazDeEntradaWebTest methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 17:16'!
test754LaInterfazDeEntradaWebInicialmenteGeneraUnModeloADibujarConUnaColeccionDeElementosAMostrarVacia

	| unSistemaDeCambios unaInterfazDeEntradaWeb resultadoEsperado |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC4.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC5.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC6.

	unaInterfazDeEntradaWeb := InterfazDeEntradaWeb new: unSistemaDeCambios.
	
	resultadoEsperado := OrderedCollection new.
	
	self assert: unaInterfazDeEntradaWeb modeloADibujar elementosAMostrar = resultadoEsperado.
	! !

!InerfazDeEntradaWebTest methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 17:57'!
test755LaInterfazDeEntradaWebGeneraUnModeloADibujarConConLosElementosAMostrar

	| unSistemaDeCambios unaInterfazDeEntradaWeb |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC4.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC5.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC6.

	unaInterfazDeEntradaWeb := InterfazDeEntradaWeb new: unSistemaDeCambios.
	unaInterfazDeEntradaWeb armarAgregandoOQuitando: 'uno'. 
	unaInterfazDeEntradaWeb armarAgregandoOQuitando: 'dos'. 
	unaInterfazDeEntradaWeb armarAgregandoOQuitando: 'tres'. 
	
	self assert: unaInterfazDeEntradaWeb modeloADibujar elementosAMostrar size = 3.
	self assert: (unaInterfazDeEntradaWeb modeloADibujar elementosAMostrar includes: 'uno').
	self assert: (unaInterfazDeEntradaWeb modeloADibujar elementosAMostrar includes: 'dos').
	self assert: (unaInterfazDeEntradaWeb modeloADibujar elementosAMostrar includes: 'tres').
	! !

!InerfazDeEntradaWebTest methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 17:57'!
test756LaInterfazDeEntradaWebGeneraUnModeloADibujarConConLosElementosAMostrar

	| unSistemaDeCambios unaInterfazDeEntradaWeb |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC4.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC5.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC6.

	unaInterfazDeEntradaWeb := InterfazDeEntradaWeb new: unSistemaDeCambios.
	
	unaInterfazDeEntradaWeb armarAgregandoOQuitando: 1.
	
	self assert: unaInterfazDeEntradaWeb modeloADibujar elementosAMostrar size = 1.
	self assert: (unaInterfazDeEntradaWeb modeloADibujar elementosAMostrar includes: 1).
	! !

ChangesTest subclass: #InerfazDeUsuarioTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InerfazDeUsuarioTest methodsFor: '04InterfazDeUsuario' stamp: 'SebastianGarbi 10/13/2013 21:37'!
test510LaInterfazDeUsusarioPuedeCerrarLaUnidadActiva
 | unSistemaDeCambios  unaInterfazDeUsuario |

 unSistemaDeCambios := SistemaDeCambios new.   

 unaInterfazDeUsuario := InterfazDeUsuario newWith: unSistemaDeCambios.
 unaInterfazDeUsuario cerrarUnidad.
 
 self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.! !

!InerfazDeUsuarioTest methodsFor: '04InterfazDeUsuario' stamp: 'SebastianGarbi 10/13/2013 22:12'!
test515LaInterfazDeUsusarioPuedePreguntarTodosLosCambiosRealizados
 | unSistemaDeCambios  unaInterfazDeUsuario unRegistroDeCambio |

 unSistemaDeCambios := SistemaDeCambios new.   
 unaInterfazDeUsuario := InterfazDeUsuario newWith: unSistemaDeCambios.
 
unRegistroDeCambio := self registroClassCreatedC1.
 
self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.
self assert: unaInterfazDeUsuario todosLosCambios size = 0.
unSistemaDeCambios registrarCambio: unRegistroDeCambio.

unaInterfazDeUsuario cerrarUnidad.
unSistemaDeCambios registrarCambio: unRegistroDeCambio.

unaInterfazDeUsuario cerrarUnidad.
 
 self assert: unSistemaDeCambios unidadesDeTrabajo size = 2.
 self assert: unaInterfazDeUsuario todosLosCambios size = 2.
! !

!InerfazDeUsuarioTest methodsFor: '04InterfazDeUsuario' stamp: 'SebastianGarbi 10/13/2013 22:13'!
test520LaInterfazDeUsusarioPuedePreguntarTodosLosCambiosRealizadosDeUnMetodoDeClase
 | unSistemaDeCambios  unaInterfazDeUsuario unRegistroDeCambio |

 unSistemaDeCambios := SistemaDeCambios new.   

 unaInterfazDeUsuario := InterfazDeUsuario newWith: unSistemaDeCambios.

" unCambio := (ClassCreatedChange newAffectedClassName: 'ChangesTest' categoryName: 'DAO-TP-Changes').
 unRegistroDeCambio := RegistroDeCambio newWithThischange: unCambio andThisAuthor: 'Seba' atThisTime: DateAndTime now."
 unRegistroDeCambio := self registroClassCreatedC1.

 self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.
 self assert: unaInterfazDeUsuario todosLosCambios size = 0.

 unSistemaDeCambios registrarCambio: unRegistroDeCambio.
 unaInterfazDeUsuario cerrarUnidad.
 
 unSistemaDeCambios registrarCambio: unRegistroDeCambio.
 unaInterfazDeUsuario cerrarUnidad.
 
 self assert: unSistemaDeCambios unidadesDeTrabajo size = 2.
 self assert: unaInterfazDeUsuario todosLosCambios size = 2.
 self assert: (unaInterfazDeUsuario todosLosCambiosDelMensajeDeClase: 'now' deLaClase: 'ChangesTest' ) size = 0.
! !

!InerfazDeUsuarioTest methodsFor: '04InterfazDeUsuario' stamp: 'SebastianGarbi 10/13/2013 22:21'!
test521LaInterfazDeUsusarioPuedePreguntarTodosLosCambiosRealizadosDeUnMetodoDeClase
 | unSistemaDeCambios  unaInterfazDeUsuario unRegistroDeCambio |

 unSistemaDeCambios := SistemaDeCambios new.   

 unaInterfazDeUsuario := InterfazDeUsuario newWith: unSistemaDeCambios.
" unCambio := ClassMethodCreatedChange
								onClass: 'ChangesTest'
								selector: 'now'
								protocol: 'as yet unclassified'
								sourceCode: 'now'.

(ClassCreatedChange newAffectedClassName: 'ChangesTest' categoryName: 'DAO-TP-Changes').
 unRegistroDeCambio := RegistroDeCambio newWithThischange: unCambio andThisAuthor: 'Seba' atThisTime: DateAndTime now."
unRegistroDeCambio := self registroClassMethodCreatedC1.

 self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.
 self assert: unaInterfazDeUsuario todosLosCambios size = 0.

 unSistemaDeCambios registrarCambio: unRegistroDeCambio.
 unaInterfazDeUsuario cerrarUnidad.
 
 unSistemaDeCambios registrarCambio: unRegistroDeCambio.
 unaInterfazDeUsuario cerrarUnidad.
 
 self assert: unSistemaDeCambios unidadesDeTrabajo size = 2.
 self assert: unaInterfazDeUsuario todosLosCambios size = 2.
 self assert: (unaInterfazDeUsuario todosLosCambiosDelMensajeDeClase: 'now' deLaClase: 'ChangesTest' ) size = 2.
! !

!InerfazDeUsuarioTest methodsFor: '04InterfazDeUsuario' stamp: 'SebastianGarbi 10/13/2013 22:25'!
test531LaInterfazDeUsusarioPuedePreguntarTodosLosCambiosRealizadosDeUnMetodoDeInstancia
 | unSistemaDeCambios  unaInterfazDeUsuario unRegistroDeCambio |

 unSistemaDeCambios := SistemaDeCambios new.   

 unaInterfazDeUsuario := InterfazDeUsuario newWith: unSistemaDeCambios.
" unCambio := InstanceMethodCreatedChange
								onClass: 'ChangesTest'
								selector: 'now'
								protocol: 'as yet unclassified'
								sourceCode: 'now'.

 unRegistroDeCambio := RegistroDeCambio newWithThischange: unCambio andThisAuthor: 'Seba' atThisTime: DateAndTime now.
"
unRegistroDeCambio := self registroInstanceMethodCreatedC1 .
 self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.
 self assert: unaInterfazDeUsuario todosLosCambios size = 0.

 unSistemaDeCambios registrarCambio: unRegistroDeCambio.
 unaInterfazDeUsuario cerrarUnidad.
 
 unSistemaDeCambios registrarCambio: unRegistroDeCambio.
 unaInterfazDeUsuario cerrarUnidad.
 
 self assert: unSistemaDeCambios unidadesDeTrabajo size = 2.
 self assert: unaInterfazDeUsuario todosLosCambios size = 2.
 self assert: (unaInterfazDeUsuario todosLosCambiosDelMensajeDeInstancia: 'now' deLaClase: 'ChangesTest' ) size = 2.
! !

ChangesTest subclass: #InterfazDeAnunciosTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 10/19/2013 19:25'!
test01LaIntefazDeAnunciosHandlea_CategoryAdded

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
 
	systemAnnouncerTest classCategoryAdded: #'DAO-TP-Changes'.
 
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio cambio = (ClassCategoryCreatedChange categoryName: #'DAO-TP-Changes')).
	]! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 10/19/2013 19:33'!
test02LaIntefazDeAnunciosHandlea_CategoryRemoved

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
 
	systemAnnouncerTest classCategoryRemoved: #'DAO-TP-Changes'.
 
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio cambio = (ClassCategoryRemovedChange categoryName: #'DAO-TP-Changes')).
	]! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 10/19/2013 19:34'!
test03LaIntefazDeAnunciosHandlea_CategoryRenamed

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
 
	systemAnnouncerTest classCategoryRenamedFrom: #'DAO-TP-Changes' to: #'DAO-TP-Changes2'.
 
	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio cambio = (ClassCategoryRenamedChange from: #'DAO-TP-Changes' to: #'DAO-TP-Changes2')).
	]! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 10/19/2013 23:24'!
test04LaIntefazDeAnunciosHandlea_ClassAdded

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada index |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	ChangesTest subclass: #Blah
		instanceVariableNames: 'uno dos'
		classVariableNames: 'Tres Cuatro'  "Las agrega en orden alfabtico"
		poolDictionaries: ''
		category: 'DAO-TP-Changes'.
 	
	systemAnnouncerTest  classAdded: Blah inCategory: 'DAO-TP-Changes'.
	
	self assert: (unSistemaDeCambios todosLosCambios size = 5).
 	index := 1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (ClassCreatedChange class: #Blah category: #'DAO-TP-Changes' superclass: #ChangesTest)).
	index:=index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (InstanceVariableCreatedChange classAffected: #Blah  variableName: 'dos' )).
	index:=index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (InstanceVariableCreatedChange classAffected: #Blah  variableName: 'uno' )).
	index:=index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (ClassVariableCreatedChange classAffected: #Blah  variableName: 'Cuatro' )).
	index:=index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (ClassVariableCreatedChange classAffected: #Blah variableName: 'Tres' )).

! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 10/19/2013 22:01'!
test05LaIntefazDeAnunciosHandlea_ClassRemoved

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada index |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	ChangesTest subclass: #Blah
		instanceVariableNames: 'uno dos'
		classVariableNames: 'Tres Cuatro'  "Las agrega en orden alfabtico"
		poolDictionaries: ''
		category: 'DAO-TP-Changes'.
 	
	systemAnnouncerTest  classRemoved: Blah fromCategory: 'DAO-TP-Changes'.
	
	self assert: (unSistemaDeCambios todosLosCambios size = 1).
 	index := 1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (
		ClassRemovedChange class: #Blah
			category: #'DAO-TP-Changes')).! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 10/19/2013 22:31'!
test06LaIntefazDeAnunciosHandlea_ClassRecategorized

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada index aClass |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	ChangesTest subclass: #Blah
		instanceVariableNames: 'uno dos'
		classVariableNames: 'Tres Cuatro'  "Las agrega en orden alfabtico"
		poolDictionaries: ''
		category: 'DAO-TP-Changes'.
	
	aClass := Blah.
	 	
	systemAnnouncerTest class: aClass recategorizedFrom: 'DAO-TP-Changes' to: 'DAO-TP-Changes2'.
	
	self assert: (unSistemaDeCambios todosLosCambios size = 1).
 	index := 1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (
		ClassRecategorizedChange classRecategorized:  #Blah oldCategory:  'DAO-TP-Changes' newCategory: 'DAO-TP-Changes2'
	)).! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'Maxii 11/9/2013 18:20'!
test07LaIntefazDeAnunciosHandlea_ClassModifiedClassDefinition

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada index unaClase otraClase |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unaClase := (ChangesTest subclass: #Blah instanceVariableNames: 'uno dos' classVariableNames: 'Tres Cuatro' poolDictionaries: 'Text TextConstants' category: 'DAO-TP-Changes2') copy.
	otraClase := (Object subclass: #Blah instanceVariableNames: 'uno cuatro' classVariableNames: 'Tres Dos' poolDictionaries: 'Text Year' category: 'DAO-TP-Changes').	
	

	systemAnnouncerTest  classDefinitionChangedFrom: unaClase to: otraClase.
	
	self assert: (unSistemaDeCambios todosLosCambios size = 7).
 	index := 1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (SuperclassChangedChange classAffected: #Blah oldSuperclass: #ChangesTest newSuperclass: #Object)).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (InstanceVariableCreatedChange classAffected: #Blah  variableName: 'cuatro' )).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (InstanceVariableRemovedChange classAffected: #Blah  variableName: 'dos' )).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (ClassVariableCreatedChange classAffected: #Blah  variableName: 'Dos' )).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (ClassVariableRemovedChange classAffected: #Blah  variableName: 'Cuatro' )).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (PoolDictionaryCreatedChange classAffected: #Blah poolDictionaryName: 'Year' )).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (PoolDictionaryRemovedChange classAffected: #Blah poolDictionaryName: 'TextConstants' )).
	! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 11/2/2013 15:23'!
test08LaIntefazDeAnunciosHandlea_MethodAdded

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada index unMetodoDeInstancia unMetodoDeClase aClassName |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unMetodoDeInstancia :=  (self class superclass methodDict  at: #now).
	unMetodoDeClase :=  (self class superclass class methodDict  at: #mensajeTest).
	aClassName := self class superclass name.
	
	systemAnnouncerTest methodAdded: unMetodoDeInstancia selector: unMetodoDeInstancia selector inProtocol: unMetodoDeInstancia protocol class: unMetodoDeInstancia  methodClass requestor: nil.
	systemAnnouncerTest methodAdded: unMetodoDeClase selector: unMetodoDeClase selector inProtocol: unMetodoDeClase protocol class: unMetodoDeClase  methodClass requestor: nil.
	
	self assert: (unSistemaDeCambios todosLosCambios size = 2).
 	index := 1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (InstanceMethodCreatedChange classAffected: aClassName methodName: #now methodCategory: unMetodoDeInstancia protocol sourceCode: unMetodoDeInstancia sourceCode)).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (ClassMethodCreatedChange classAffected: aClassName methodName: #mensajeTest methodCategory: unMetodoDeClase protocol sourceCode: unMetodoDeClase sourceCode)).
! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 11/2/2013 15:23'!
test09LaIntefazDeAnunciosHandlea_MethodRemoved

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada index unMetodoDeInstancia unMetodoDeClase aClassName |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unMetodoDeInstancia :=  (self class superclass methodDict  at: #now).
	unMetodoDeClase :=  (self class superclass class methodDict  at: #mensajeTest).
	aClassName := self class superclass name.
	
	systemAnnouncerTest methodRemoved: unMetodoDeInstancia selector: unMetodoDeInstancia selector inProtocol: unMetodoDeInstancia protocol class: unMetodoDeInstancia  methodClass origin: unMetodoDeInstancia origin.
	systemAnnouncerTest methodRemoved: unMetodoDeClase selector: unMetodoDeClase selector inProtocol: unMetodoDeClase protocol class: unMetodoDeClase  methodClass origin: unMetodoDeClase origin.
	
	self assert: (unSistemaDeCambios todosLosCambios size = 2).
 	index := 1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (InstanceMethodRemovedChange classAffected: aClassName methodName: #now methodCategory: unMetodoDeInstancia protocol sourceCode: unMetodoDeInstancia sourceCode)).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (ClassMethodRemovedChange classAffected: aClassName methodName: #mensajeTest methodCategory: unMetodoDeClase protocol sourceCode: unMetodoDeClase sourceCode)).
! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 10/20/2013 19:07'!
test10LaIntefazDeAnunciosHandlea_MethodRecategorized

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada index unMetodoDeInstancia unMetodoDeClase aClassName aProtocol aNewProtocol |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unMetodoDeInstancia :=  (self class superclass methodDict  at: #now).
	unMetodoDeClase :=  (self class superclass class methodDict  at: #mensajeTest).
	aClassName := self class superclass name.
	aProtocol := 'as yet unclassified'.
	aNewProtocol := 'categoryTest'.
	
	systemAnnouncerTest  selector: #now recategorizedFrom:  aProtocol to: aNewProtocol inClass: ChangesTest.
	systemAnnouncerTest  selector: #mensajeTest recategorizedFrom: aProtocol to: aNewProtocol inClass: ChangesTest class.
	
	self assert: (unSistemaDeCambios todosLosCambios size = 2).
 	index := 1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (InstanceMethodRecategorizedChange classAffected: aClassName methodName: unMetodoDeInstancia selector oldMethodCategory: aProtocol newMethodCategory: aNewProtocol)).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (ClassMethodRecategorizedChange classAffected: aClassName methodName: unMetodoDeClase selector oldMethodCategory: aProtocol newMethodCategory: aNewProtocol)).
! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 11/2/2013 15:24'!
test11LaIntefazDeAnunciosHandlea_MethodModified

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada index unMetodoDeInstancia unMetodoDeClase aClassName unMetodoDeInstanciaModificado unMetodoDeClaseModificado |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	
	unMetodoDeInstancia :=  (ChangesTest methodDict  at: #mensajeTestInstancia).
	unMetodoDeInstanciaModificado := unMetodoDeInstancia.
	unMetodoDeClase :=  (ChangesTest class methodDict  at: #mensajeTest).
	unMetodoDeClaseModificado  := unMetodoDeClase.
	aClassName := ChangesTest name.
	
	systemAnnouncerTest
		methodChangedFrom: unMetodoDeInstancia
		to: unMetodoDeInstanciaModificado
		selector: unMetodoDeInstanciaModificado selector
		inClass: ChangesTest
		oldProtocol: unMetodoDeInstancia protocol
		newProtocol: unMetodoDeInstanciaModificado protocol
		requestor: nil.
	systemAnnouncerTest
		methodChangedFrom: unMetodoDeClase
		to: unMetodoDeClaseModificado
		selector: unMetodoDeClaseModificado selector
		inClass: ChangesTest class
		oldProtocol: unMetodoDeClase protocol
		newProtocol: unMetodoDeClaseModificado protocol
		requestor: nil.
	
	self assert: (unSistemaDeCambios todosLosCambios size = 2).
 	index := 1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (
		InstanceMethodChangedChange
			classAffected: aClassName
			methodName: #mensajeTestInstancia
			oldSourceCode: unMetodoDeInstancia sourceCode
			newSourceCode: unMetodoDeInstanciaModificado sourceCode)).
	index := index+1.
	self assert: ((unSistemaDeCambios todosLosCambios at: index) cambio = (
		ClassMethodChangedChange
			classAffected: aClassName
			methodName: #mensajeTest
			oldSourceCode: unMetodoDeClase sourceCode
			newSourceCode: unMetodoDeClaseModificado sourceCode)).
! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'Maxii 10/31/2013 23:05'!
test12LaIntefazDeAnunciosHandlea_ClassReorganized

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada categorias |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
 	
	systemAnnouncerTest  classReorganized: ChangesTestClaseEstaticaDePrueba.


	categorias := ChangesTestClaseEstaticaDePrueba organization categories.
	self assert: (unSistemaDeCambios todosLosCambios size = 1).
 	self assert: ( ( unSistemaDeCambios todosLosCambios at: 1 ) cambio = ( InstanceMethodCategoyReorganizedChange class: #ChangesTestClaseEstaticaDePrueba with: categorias ) ).
	! !

!InterfazDeAnunciosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'Maxii 10/31/2013 23:16'!
test13LaIntefazDeAnunciosHandlea_ClassReorganized

	| systemAnnouncerTest unSistemaDeCambios unaInterfaceDeEventosDeEntrada categorias |
	
	systemAnnouncerTest := self unSystemAnnouncer.
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
 
	InterfazParaAnuncios newWith: systemAnnouncerTest and: unaInterfaceDeEventosDeEntrada.
 	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
 	
	systemAnnouncerTest  classReorganized: ChangesTestClaseEstaticaDePrueba class.


	categorias := ChangesTestClaseEstaticaDePrueba class organization categories.
	self assert: (unSistemaDeCambios todosLosCambios size = 1).
 	self assert: ( ( unSistemaDeCambios todosLosCambios at: 1 ) cambio = ( ClassMethodCategoyReorganizedChange class: #ChangesTestClaseEstaticaDePrueba with: categorias ) ).
	! !

ChangesTest subclass: #SistemaDeCambiosTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!SistemaDeCambiosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'SebastianGarbi 10/19/2013 19:02'!
test010ElSistemaDebeCrearUnaUnidadCuandoLaActualEsteCerradaYSeRegistreUnCambio
	| unSistemaDeCambios |

	unSistemaDeCambios := SistemaDeCambios new.
	
	self assert: (unSistemaDeCambios unidadesDeTrabajo size = 1).
	self assert: (unSistemaDeCambios todosLosCambios size = 0).

	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	self assert: (unSistemaDeCambios unidadesDeTrabajo size = 1).
	self assert: (unSistemaDeCambios todosLosCambios size = 2).
			
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	
	self assert: (unSistemaDeCambios unidadesDeTrabajo size = 2).
	self assert: (unSistemaDeCambios todosLosCambios size = 3).
! !

!SistemaDeCambiosTest methodsFor: '03InterfaceDeEventosDeEntrada' stamp: 'Maxii 10/21/2013 12:22'!
test011UnCambioDebeSaberEnQueMomentoFueRealizadoYPorQuien
	
	| unSistemaDeCambios |

	unSistemaDeCambios := SistemaDeCambios new.
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.

	unSistemaDeCambios todosLosCambios do: [ :unRegistroDeCambio | 
		self assert: (unRegistroDeCambio autor = self autorTest fullName).
		self assert: (unRegistroDeCambio fechaYHora = (DateAndTime year: 2013 day: 1) ).
	]
	
	! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'SebastianGarbi 10/13/2013 21:37'!
test200UnSistemaDeCambiosSeInicializaConUnaUnidadDeTrabajoActivaVacia
	
	| unSistemaDeCambios |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.
	self assert: unSistemaDeCambios unidadActiva todosLosCambios size = 0.! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'SebastianGarbi 10/13/2013 21:37'!
test201ElSistemaRegistraElCambioEnLaUnidadActiva
	
	| unSistemaDeCambios unaUnidadDeTrabajo |

	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	unaUnidadDeTrabajo := unSistemaDeCambios unidadActiva. 

	self assert: unaUnidadDeTrabajo todosLosCambios size = 1.
	self assert: (unaUnidadDeTrabajo todosLosCambios allSatisfy: [ :unCambio | unCambio = self registroClassCreatedC1 ]).
	self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'SebastianGarbi 10/13/2013 21:37'!
test202ElSistemaAlCerrarLaUnidadActivaSoloTieneUnidadesDeTrabajoCerradas
	
	| unSistemaDeCambios |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.
	self assert: ( unSistemaDeCambios unidadesDeTrabajo allSatisfy: [ :unaUnidadDeTrabajo | unaUnidadDeTrabajo estaCerrada ] ).! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'Maxii 10/26/2013 18:55'!
test203ElSistemaAlCerrarLaUnidadActivaNoCreaUnaUnidadNueva
	
	| unSistemaDeCambios |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	self assert: unSistemaDeCambios unidadesDeTrabajo size = 1.! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'SebastianGarbi 10/19/2013 18:47'!
test210ElSistemaPuedeCrearCambiosEnDistintasUnidades
	| unSistemaDeCambios unaInterfaceDeEventosDeEntrada unCambio |
	unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
	unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unCambio := self registroClassCreatedC1.
	unaInterfaceDeEventosDeEntrada handle: unCambio.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unaInterfaceDeEventosDeEntrada handle: unCambio.
	unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	unaInterfaceDeEventosDeEntrada handle: unCambio.
	self assert: unSistemaDeCambios unidadesDeTrabajo size = 4.
	self assert: unSistemaDeCambios todosLosCambios size = 3.
	unSistemaDeCambios todosLosCambios
		allSatisfy: [ :unRegistroDeCambio |
			unRegistroDeCambio autor = self autorTest fullName and: unRegistroDeCambio fechaYHora = self relojTest now ]! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'Maxii 10/21/2013 12:49'!
test211ElSistemaPuedeObtenerLaHistoriaDeUnMetodoDeClase
 | unSistemaDeCambios unaInterfaceDeEventosDeEntrada aClassName aCategory aMethodName aProtocol aSourceCode |

unaInterfaceDeEventosDeEntrada := self interfazDeEntradaInicializada.
unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.

aClassName := 'ChangesTest'.
aCategory := 'DAO-TP-Changes'.
aMethodName := 'now'.
aProtocol := 'as yet unclassified'.
aSourceCode := '^ fechaYHoraTest'.

unaInterfaceDeEventosDeEntrada classCreated: aClassName inCategory: aCategory superclass: self class name.
unaInterfaceDeEventosDeEntrada instanceMethod: aMethodName createdOn: aClassName inCategory: aProtocol withCode: aSourceCode.
unaInterfaceDeEventosDeEntrada classMethod: aMethodName createdOn: aClassName inCategory: aProtocol withCode: aSourceCode.
unaInterfaceDeEventosDeEntrada classMethod: aMethodName createdOn: aClassName inCategory: aProtocol withCode: aSourceCode.

unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
unaInterfaceDeEventosDeEntrada classMethod: aMethodName createdOn: aClassName inCategory: aProtocol withCode: aSourceCode.

unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
unaInterfaceDeEventosDeEntrada classMethod: aMethodName createdOn: aClassName inCategory: aProtocol withCode: aSourceCode.

self assert: unSistemaDeCambios unidadesDeTrabajo size = 3.
self assert: unSistemaDeCambios todosLosCambios size = 6.
self assert: (unSistemaDeCambios historiaDelMetodoDeClase: aMethodName deLaClase: aClassName) size = 4. 
 ! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'Maxii 10/21/2013 13:05'!
test212ElSistemaPuedeObtenerLaHistoriaDeUnMetodoDeInstancia
 | unSistemaDeCambios unaInterfaceDeEventosDeEntrada unCambio otroCambio otroCambio2 otroCambio3 |

 unaInterfaceDeEventosDeEntrada:= self interfazDeEntradaInicializada.
 unSistemaDeCambios := unaInterfaceDeEventosDeEntrada sistemaDeCambios.
   

 unCambio := ClassCreatedChange class: 'ChangesTest' category: 'DAO-TP-Changes' superclass:  self class name.

 unaInterfaceDeEventosDeEntrada handle: unCambio.

 otroCambio :=  (InstanceMethodCreatedChange  	classAffected: 'ChangesTest' 
													methodName: 'now' 
													methodCategory: 'as yet unclassified' 
													sourceCode: 'now
	^ fechaYHoraTest' ).
otroCambio2 := (ClassMethodCreatedChange   	classAffected: 'ChangesTest' 
													methodName: 'now' 
													methodCategory: 'as yet unclassified' 
													sourceCode: 'now
	^ fechaYHoraTest' ).
 otroCambio3 :=  (InstanceMethodCreatedChange  	classAffected: 'ChangesTest' 
													methodName: 'notNow' 
													methodCategory: 'as yet unclassified' 
													sourceCode: 'now
	^ fechaYHoraTest' ).

unaInterfaceDeEventosDeEntrada handle: otroCambio.
unaInterfaceDeEventosDeEntrada handle: otroCambio2.
unaInterfaceDeEventosDeEntrada handle: otroCambio3.
																						
 unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
 unaInterfaceDeEventosDeEntrada handle: otroCambio.

 unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
 unaInterfaceDeEventosDeEntrada handle: otroCambio.
 
 self assert: unSistemaDeCambios unidadesDeTrabajo size = 3.
 self assert: unSistemaDeCambios todosLosCambios size = 6.
 self assert: ( unSistemaDeCambios historiaDelMetodoDeInstancia: 'now' deLaClase: 'ChangesTest' ) size = 3.
 self assert: ( (unSistemaDeCambios historiaDelMetodoDeInstancia: 'now' deLaClase: 'ChangesTest') allSatisfy: [ :unRegistroDeCambio | 
										((unRegistroDeCambio autor = self autorTest fullName ) 
  										and: unRegistroDeCambio fechaYHora = self relojTest now) 
										and: unRegistroDeCambio cambio = otroCambio
										] ).! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'SebastianGarbi 10/13/2013 21:37'!
test220ElSistemaAlCerrarLaUnidadActivaLeAsignaUnID
	
	| unSistemaDeCambios id01 id02 |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	id01 := unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	id02 := unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	
	self assert: unSistemaDeCambios todosLosCambios size = 3.
	self assert: unSistemaDeCambios unidadesDeTrabajo size = 3.
	self deny: id01 = id02.! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'Maxii 10/18/2013 12:34'!
test230ElSistemaPuedeDevolverTodosLosCambiosDeUnaUnidadDeTrabajo
	
	| unSistemaDeCambios id01 id02 todosLosCambiosDeLaUnidad02 |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	id01 := unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	id02 := unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	
	todosLosCambiosDeLaUnidad02 := unSistemaDeCambios todosLosCambiosDe: id02.
	
	self assert: todosLosCambiosDeLaUnidad02 size = 1.
	self assert: ( todosLosCambiosDeLaUnidad02 allSatisfy: [ :unRegistro | unRegistro = self registroClassCreatedC2 ] ).
	self assert: unSistemaDeCambios unidadesDeTrabajo size = 3.
	self deny: id01 = id02.
	
! !

!SistemaDeCambiosTest methodsFor: '02SistemaDeCambios' stamp: 'Maxii 10/18/2013 12:34'!
test231ElSistemaPuedeDevolverTodosLosIDsDeLasUnidadesDeTrabajo
	
	| unSistemaDeCambios id01 id02 |
	
	unSistemaDeCambios := SistemaDeCambios new.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC1.
	id01 := unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC2.
	id02 := unSistemaDeCambios cerrarUnidadDeTrabajoActiva.
	
	unSistemaDeCambios registrarCambio: self registroClassCreatedC3.
	
	self assert: unSistemaDeCambios idsDeUnidadesDeTrabajo size = 2.
	self assert: ( unSistemaDeCambios idsDeUnidadesDeTrabajo includes: id01 ).
	self assert: ( unSistemaDeCambios idsDeUnidadesDeTrabajo includes: id02 ).
	
	"
	self assert: ( todosLosCambiosDeLaUnidad02 allSatisfy: [ :unRegistro | unRegistro = self registroClassCreatedC2 ] ).
	self assert: unSistemaDeCambios unidadesDeTrabajo size = 3.
	self deny: id01 = id02.
	"
! !

ChangesTest subclass: #UnidadDeTrabajoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!UnidadDeTrabajoTest methodsFor: '01UnidadDeTrabajoTest' stamp: 'SebastianGarbi 10/13/2013 21:34'!
test001LaUnidadDeTrabajoInicialNoSabeResponderElMensajePadre
	| unaUnidadDeTrabajoInicial |
	unaUnidadDeTrabajoInicial := UnidadDeTrabajoInicial new.
	self should: [ unaUnidadDeTrabajoInicial padre ]
			raise:  MessageNotUnderstood 
			withExceptionDo: [ :aMessageNotUnderstood  | aMessageNotUnderstood messageText = '#padre' ]
! !

!UnidadDeTrabajoTest methodsFor: '01UnidadDeTrabajoTest' stamp: 'SebastianGarbi 10/13/2013 21:34'!
test002UnaUnidadDeTrabajoSeCreaSinCambiosYAbierta
	| unaUnidadDeTrabajo |
	unaUnidadDeTrabajo := UnidadDeTrabajoReal newWith: self algunaUnidadDeTrabajo.
	self assert: unaUnidadDeTrabajo todosLosCambios isEmpty.
	self deny: unaUnidadDeTrabajo estaCerrada.
	
	unaUnidadDeTrabajo := UnidadDeTrabajoInicial new.
	self assert: unaUnidadDeTrabajo todosLosCambios isEmpty.
	self deny: unaUnidadDeTrabajo estaCerrada.! !

!UnidadDeTrabajoTest methodsFor: '01UnidadDeTrabajoTest' stamp: 'SebastianGarbi 10/13/2013 21:34'!
test003UnaUnidadDeTrabajoQueRegistraUnCambioNoEstaVacia
	
	| unaUnidadDeTrabajo |
	unaUnidadDeTrabajo := UnidadDeTrabajoReal newWith: self algunaUnidadDeTrabajo.
	unaUnidadDeTrabajo registrarCambio: self registroClassCreatedC1.
	self deny: unaUnidadDeTrabajo todosLosCambios isEmpty.! !

!UnidadDeTrabajoTest methodsFor: '01UnidadDeTrabajoTest' stamp: 'SebastianGarbi 10/13/2013 21:34'!
test004RegistrarUnCambioEnUnidadCerradaLanzaUnaExcepcion
	
	| unaUnidadDeTrabajo |
	
	unaUnidadDeTrabajo := UnidadDeTrabajoReal newWith: self algunaUnidadDeTrabajo .
	unaUnidadDeTrabajo cerrar.

	self should: [ unaUnidadDeTrabajo registrarCambio: self registroClassCreatedC1 ] raise: Error withExceptionDo:  [ :anError | anError messageText  = UnidadDeTrabajoReal noSePuedeRegistrarCambios.
	self assert: unaUnidadDeTrabajo todosLosCambios isEmpty ].

	! !

!UnidadDeTrabajoTest methodsFor: '01UnidadDeTrabajoTest' stamp: 'SebastianGarbi 10/13/2013 21:34'!
test007UnaunidadDeTrabajoRealConoceASuPadre
	| unaUnidadDeTrabajoPadre unaUnidadDeTrabajo |
	unaUnidadDeTrabajoPadre := self algunaUnidadDeTrabajo.
	unaUnidadDeTrabajo  := UnidadDeTrabajoReal newWith: unaUnidadDeTrabajoPadre.
	self assert: (unaUnidadDeTrabajo padre = unaUnidadDeTrabajoPadre).! !

Object subclass: #CategorizadorDeChanges
	instanceVariableNames: 'resultado'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!CategorizadorDeChanges methodsFor: 'evaluate' stamp: 'SebastianGarbi 11/3/2013 12:47'!
categorizar: anOrderedCollection 
	anOrderedCollection do: [ :unChange |
		unChange accept: self.
	 ].
	^resultado.! !

!CategorizadorDeChanges methodsFor: 'initialize-release' stamp: 'SebastianGarbi 10/26/2013 23:10'!
initialize
	resultado := Dictionary new.! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:24'!
insertar: aRegistroDeCambio categorizadoEn: aByteString 
	| primerNivel segundoNivel |
	primerNivel := resultado at: aByteString ifAbsentPut: Dictionary new.
	segundoNivel := primerNivel at: aRegistroDeCambio cambio evento ifAbsentPut: OrderedCollection new.
	segundoNivel add: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:20'!
insertarEnCategoria: aRegistroDeCambio 
	| primerNivel segundoNivel |
	primerNivel := resultado at: 'Categoria' ifAbsentPut: Dictionary new.
	segundoNivel := primerNivel at: aRegistroDeCambio cambio evento ifAbsentPut: OrderedCollection new.
	segundoNivel add: aRegistroDeCambio.
	
! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:24'!
insertarEnClase: aRegistroDeCambio 
	self insertar: aRegistroDeCambio categorizadoEn: 'Clase'.! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:30'!
insertarEnMetodoDeClase: aRegistroDeCambio 
	self insertar: aRegistroDeCambio categorizadoEn: 'Metodo de Clase'.! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:32'!
insertarEnMetodoDeInstancia: aRegistroDeCambio 
	self insertar: aRegistroDeCambio categorizadoEn: 'Metodo de Instancia'.! !

!CategorizadorDeChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 13:20'!
insertarEnPoolDictionary: aRegistroDeCambio 
	self insertar: aRegistroDeCambio categorizadoEn: 'PoolDictionary'.! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:29'!
insertarEnProtocolo: aRegistroDeCambio 
	self insertar: aRegistroDeCambio categorizadoEn: 'Protocolo'.! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:27'!
insertarEnVariableDeClase: aRegistroDeCambio 
	self insertar: aRegistroDeCambio categorizadoEn: 'Variable de Clase'.! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:26'!
insertarEnVariableDeInstancia: aRegistroDeCambio 
	self insertar: aRegistroDeCambio categorizadoEn: 'Variable de Instancia'.! !

!CategorizadorDeChanges methodsFor: 'inserts' stamp: 'SebastianGarbi 11/3/2013 12:34'!
insertarEnVariableDeInstanciaDeClase: aRegistroDeCambio 
	self insertar: aRegistroDeCambio categorizadoEn: 'Variable de Instancia de Clase'.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:16'!
visitClassCategoryCreatedChange: aClassCategoryCreatedChange with: aRegistroDeCambio 
	self insertarEnCategoria: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:44'!
visitClassCategoryRemovedChange: aClassCategoryRemovedChange with: aRegistroDeCambio 
	self insertarEnCategoria: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:44'!
visitClassCategoryRenamedChange: aClassCategoryRenamedChange with: aRegistroDeCambio 
	self insertarEnCategoria: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:21'!
visitClassCreatedChange: aClassCreatedChange with: aRegistroDeCambio 
	self insertarEnClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:36'!
visitClassInstanceVariableCreatedChange: aClassInstanceVariableCreatedChange with: aRegistroDeCambio 
	self insertarEnVariableDeInstanciaDeClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:33'!
visitClassInstanceVariableRemovedChange: aClassInstanceVariableRemovedChange with: aRegistroDeCambio 
	self insertarEnVariableDeInstanciaDeClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:38'!
visitClassMethodCategoyReorganizedChange: aClassMethodCategoyReorganizedChange with: aRegistroDeCambio 
	self insertarEnProtocolo: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:30'!
visitClassMethodChangedChange: aClassMethodChangedChange with: aRegistroDeCambio 
	self insertarEnMetodoDeClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:29'!
visitClassMethodCreatedChange: aClassMethodCreatedChange with: aRegistroDeCambio 
	self insertarEnMetodoDeClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:31'!
visitClassMethodRecategorizedChange: aClassMethodRecategorizedChange with: aRegistroDeCambio 
	self insertarEnMetodoDeClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:31'!
visitClassMethodRemovedChange: aClassMethodRemovedChange with: aRegistroDeCambio 
	self insertarEnMetodoDeClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:38'!
visitClassRecategorizedChange: aClassRecategorizedChange with: aRegistroDeCambio 
	self insertarEnClase: aRegistroDeCambio .! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:25'!
visitClassRemovedChange: aClassRemovedChange with: aRegistroDeCambio 
	self insertarEnClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:26'!
visitClassVariableCreatedChange: aClassVariableCreatedChange with: aRegistroDeCambio 
	self insertarEnVariableDeClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:28'!
visitClassVariableRemovedChange: aClassVariableRemovedChange with: aRegistroDeCambio 
	self insertarEnVariableDeClase: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:28'!
visitInstanceMethodCategoyReorganizedChange: anInstanceMethodCategoyReorganizedChange with: aRegistroDeCambio 
	self insertarEnProtocolo: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:32'!
visitInstanceMethodChangedChange: anInstanceMethodChangedChange with: aRegistroDeCambio 
	self insertarEnMetodoDeInstancia: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:37'!
visitInstanceMethodCreatedChange: anInstanceMethodCreatedChange with: aRegistroDeCambio 
	self insertarEnMetodoDeInstancia: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:37'!
visitInstanceMethodRecategorizedChange: anInstanceMethodRecategorizedChange with: aRegistroDeCambio 
	self insertarEnMetodoDeInstancia: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:37'!
visitInstanceMethodRemovedChange: anInstanceMethodRemovedChange with: aRegistroDeCambio 
	self insertarEnMetodoDeInstancia: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:25'!
visitInstanceVariableCreatedChange: anInstanceVariableCreatedChange with: aRegistroDeCambio 
	self insertarEnVariableDeInstancia: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:27'!
visitInstanceVariableRemovedChange: anInstanceVariableRemovedChange with: aRegistroDeCambio 
	self insertarEnVariableDeInstancia: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 13:16'!
visitPoolDictionaryCreatedChange: aPoolDictionaryCreatedChange with: aRegistroDeCambio 
	self insertarEnPoolDictionary: aRegistroDeCambio.! !

!CategorizadorDeChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 13:22'!
visitPoolDictionaryRemovedChange: aPoolDictionaryRemovedChange with: aRegistroDeCambio 
	
	self insertarEnPoolDictionary: aRegistroDeCambio. ! !

!CategorizadorDeChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 12:38'!
visitSuperclassChangedChange: aSuperclassChangedChange with: aRegistroDeCambio 
	self insertarEnClase: aRegistroDeCambio.! !

Object subclass: #Change
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!Change class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:03'!
evento
	self subclassResponsibility.! !

!Change methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 19:27'!
= unChange 
	self subclassResponsibility .
	! !

!Change methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:26'!
accept: aVisitor return: aRegistroDeCambio 
	self subclassResponsibility.
	"^aVisitor perform: 'visit',self class name,':' with: aRegistroDeCambio."
! !

!Change methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:02'!
evento
	^self class evento.! !

Change subclass: #ClassCategoryCreatedChange
	instanceVariableNames: 'categoryName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassCategoryCreatedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:11'!
categoryName: aCategory
	^self new categoryName: aCategory.! !

!ClassCategoryCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:55'!
evento
	^'ClassCategoryCreated'! !

!ClassCategoryCreatedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/19/2013 19:30'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		unChange categoryName = self categoryName
	).! !

!ClassCategoryCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:19'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassCategoryCreatedChange: self with: aRegistroDeCambio.
! !

!ClassCategoryCreatedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/13/2013 19:11'!
categoryName
	^ categoryName! !

!ClassCategoryCreatedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/13/2013 19:11'!
categoryName: anObject
	categoryName := anObject! !

Change subclass: #ClassCategoryRemovedChange
	instanceVariableNames: 'categoryName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassCategoryRemovedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:12'!
categoryName: aByteSymbol 
	^self new categoryName: aByteSymbol.! !

!ClassCategoryRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:55'!
evento
	^'ClassCategoryRemoved'! !

!ClassCategoryRemovedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/19/2013 19:30'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		unChange categoryName = self categoryName
	).! !

!ClassCategoryRemovedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 11/2/2013 16:33'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassCategoryRemovedChange: self whith: aRegistroDeCambio.
! !

!ClassCategoryRemovedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/13/2013 19:12'!
categoryName
	^ categoryName! !

!ClassCategoryRemovedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/13/2013 19:12'!
categoryName: anObject
	categoryName := anObject! !

Change subclass: #ClassCategoryRenamedChange
	instanceVariableNames: 'oldCategoryName newCategoryName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassCategoryRenamedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:55'!
evento
	^'ClassCategoryRenamed'! !

!ClassCategoryRenamedChange class methodsFor: 'as yet unclassified' stamp: 'SebastinGarbi 9/30/2013 01:13'!
from: oldName to: newName
	^self new oldCategoryName: oldName newCategoryName: newName.
	! !

!ClassCategoryRenamedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 19:31'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		(self oldCategoryName = unChange oldCategoryName) and:
		(self newCategoryName = unChange newCategoryName)
	).! !

!ClassCategoryRenamedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:33'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassCategoryRenamedChange: self whith: aRegistroDeCambio.
! !

!ClassCategoryRenamedChange methodsFor: 'as yet unclassified' stamp: 'SebastinGarbi 9/30/2013 01:15'!
newCategoryName
	^ newCategoryName! !

!ClassCategoryRenamedChange methodsFor: 'as yet unclassified' stamp: 'SebastinGarbi 9/30/2013 01:15'!
oldCategoryName
	^ oldCategoryName! !

!ClassCategoryRenamedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 12/6/2013 12:41'!
oldCategoryName: oldName newCategoryName: newName
	oldCategoryName := oldName.
	newCategoryName := newName.! !

Change subclass: #ClassCreatedChange
	instanceVariableNames: 'classCreated classCategory superclass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassCreatedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 20:21'!
class: aClassName category: aCategoryName superclass: aSuperclassName
	^self new classCreated: aClassName classCategory: aCategoryName superclass: aSuperclassName.! !

!ClassCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:50'!
evento
	^'ClassCreated'! !

!ClassCreatedChange class methodsFor: 'as yet unclassified' stamp: 'SebastinGarbi 9/29/2013 21:33'!
nuevo
	^self new.! !

!ClassCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 19:44'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		(self classCreated = unChange classCreated) and:
		(self classCategory = unChange classCategory)
	).! !

!ClassCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:20'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassCreatedChange: self with: aRegistroDeCambio.
! !

!ClassCreatedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/13/2013 18:09'!
classCategory
	^ classCategory! !

!ClassCreatedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/13/2013 18:09'!
classCreated
	^ classCreated! !

!ClassCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 20:20'!
classCreated: aClassName  classCategory: aCategoryName superclass: aSuperClassName
	classCreated := aClassName.
	classCategory := aCategoryName.
	superclass := aSuperClassName.! !

!ClassCreatedChange methodsFor: 'accessing' stamp: 'SebastianGarbi 10/19/2013 20:19'!
superclass
	^ superclass.! !

Change subclass: #ClassInstanceVariableCreatedChange
	instanceVariableNames: 'classAffected variableName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassInstanceVariableCreatedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:33'!
classAffected: aClassName variableName: aVariableName
	^self new classAffected: aClassName variableName: aVariableName.! !

!ClassInstanceVariableCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:56'!
evento
	^'ClassInstanceVariableCreated'! !

!ClassInstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 21:40'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classAffected = unChange classAffected and:
		self	 variableName = unChange variableName
	).! !

!ClassInstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:20'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassInstanceVariableCreatedChange: self with: aRegistroDeCambio.
! !

!ClassInstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:34'!
classAffected
	^ classAffected! !

!ClassInstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:53'!
classAffected: aClassName variableName: aVariableName
	classAffected := aClassName.
	variableName := aVariableName.
	! !

!ClassInstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:34'!
variableName
	^ variableName! !

Change subclass: #ClassInstanceVariableRemovedChange
	instanceVariableNames: 'classAffected variableName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

ClassInstanceVariableRemovedChange class
	instanceVariableNames: 'classAffected variableName'!

ClassInstanceVariableRemovedChange class
	instanceVariableNames: 'classAffected variableName'!

!ClassInstanceVariableRemovedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:59'!
classAffected: aClassName variableName: aVariableName
	^self new classAffected: aClassName variableName: aVariableName.
	! !

!ClassInstanceVariableRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:56'!
evento
	^'ClassInstanceVariableRemoved'! !

!ClassInstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 21:40'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classAffected = unChange classAffected and:
		self	 variableName = unChange variableName
	).! !

!ClassInstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:20'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassInstanceVariableRemovedChange: self with: aRegistroDeCambio.
! !

!ClassInstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:58'!
classAffected
	^classAffected.! !

!ClassInstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:58'!
classAffected: aClassName variableName: aVariableName
	classAffected := aClassName.
	variableName := aVariableName.
	! !

!ClassInstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:58'!
variableName
	^ variableName! !

Change subclass: #ClassMethodCategoyReorganizedChange
	instanceVariableNames: 'classAffected arrayDeCategorias'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassMethodCategoyReorganizedChange class methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 23:12'!
class: unNombredeClase with: unArrayDeCategorias 
	^self new initializeWithClassName: unNombredeClase with: unArrayDeCategorias.! !

!ClassMethodCategoyReorganizedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:56'!
evento
	^'ClassMethodCategoyReorganized'.! !

!ClassMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 23:17'!
= unChange 
	(unChange isKindOf: self class) ifFalse:[^false].
	^ classAffected = unChange classAffected and: arrayDeCategorias = unChange arrayDeCategorias
	 ! !

!ClassMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:20'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassMethodCategoyReorganizedChange: self with: aRegistroDeCambio.
! !

!ClassMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 23:18'!
arrayDeCategorias
	^ arrayDeCategorias! !

!ClassMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 23:18'!
classAffected
	^ classAffected! !

!ClassMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 23:13'!
initializeWithClassName: unNombreDeClase with: unArrayDeCategorias 

	classAffected := unNombreDeClase.
	arrayDeCategorias := unArrayDeCategorias.! !

Change subclass: #ClassMethodChangedChange
	instanceVariableNames: 'classAffected methodName oldSourceCode newSourceCode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassMethodChangedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 19:46'!
classAffected: aClassName methodName: aMethodName oldSourceCode: anOldSource newSourceCode: aNewSource
	^self new classAffected: aClassName methodName: aMethodName oldSourceCode: anOldSource newSourceCode: aNewSource
! !

!ClassMethodChangedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:56'!
evento 
	^'ClassMethodChanged'! !

!ClassMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 19:56'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		((self classAffected = unChange classAffected and:
		self	 methodName = unChange methodName) and: 
		self newSourceCode = unChange newSourceCode) and: 
		self oldSourceCode = unChange oldSourceCode
	).! !

!ClassMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:29'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassMethodChangedChange: self with: aRegistroDeCambio.! !

!ClassMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:06'!
classAffected
	^classAffected! !

!ClassMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:06'!
classAffected: aClassName methodName: aMethodName oldSourceCode: anOldSource newSourceCode: aNewSource
	classAffected := aClassName.
	methodName := aMethodName.
	oldSourceCode := anOldSource.
	newSourceCode := aNewSource. ! !

!ClassMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:06'!
methodName
	^ methodName! !

!ClassMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:10'!
newSourceCode
	^newSourceCode.! !

!ClassMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:10'!
oldSourceCode
	^oldSourceCode.! !

Change subclass: #ClassMethodCreatedChange
	instanceVariableNames: 'classAffected methodName methodCategory sourceCode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassMethodCreatedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:35'!
classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode
	^self new classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode.! !

!ClassMethodCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:57'!
evento
	^'ClassMethodCreated'! !

!ClassMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 18:16'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		((self classAffected = unChange classAffected and:
		self	 methodCategory = unChange methodCategory) and: 
		self methodName = unChange methodName) and: 
		self sourceCode = unChange sourceCode
	).! !

!ClassMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:30'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassMethodCreatedChange: self with: aRegistroDeCambio.! !

!ClassMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:36'!
classAffected
	^ classAffected! !

!ClassMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:36'!
classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode
	classAffected := aClassName.
	methodName := aMethodName.
	methodCategory := aProtocol.
	sourceCode := aSourceCode. ! !

!ClassMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:36'!
methodCategory
	^ methodCategory! !

!ClassMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:36'!
methodName
	^ methodName! !

!ClassMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:37'!
sourceCode
	^ sourceCode! !

Change subclass: #ClassMethodRecategorizedChange
	instanceVariableNames: 'classAffected methodName oldMethodCategory newMethodCategory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassMethodRecategorizedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:53'!
classAffected: aClassName methodName: aMethodName oldMethodCategory: aProtocol newMethodCategory: aNewProtocol
	^self new classAffected: aClassName methodName: aMethodName oldMethodCategory: aProtocol newMethodCategory: aNewProtocol.! !

!ClassMethodRecategorizedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:57'!
evento
	^'ClassMethodRecategorized'! !

!ClassMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 19:09'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		(self classAffected = unChange classAffected and:
		self	 methodName = unChange methodName) and:
		(self newMethodCategory = unChange newMethodCategory and: 
		self oldMethodCategory = unChange oldMethodCategory)
	).! !

!ClassMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:30'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassMethodRecategorizedChange: self with: aRegistroDeCambio.! !

!ClassMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:55'!
classAffected
	^ classAffected! !

!ClassMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:55'!
classAffected: aClassName methodName: aMethodName oldMethodCategory: aProtocol newMethodCategory: aNewProtocol
	classAffected := aClassName.
	methodName := aMethodName.
	oldMethodCategory := aProtocol.
	newMethodCategory := aNewProtocol. ! !

!ClassMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:55'!
methodName
	^ methodName! !

!ClassMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:55'!
newMethodCategory
	^ newMethodCategory! !

!ClassMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:55'!
oldMethodCategory
	^ oldMethodCategory! !

Change subclass: #ClassMethodRemovedChange
	instanceVariableNames: 'classAffected methodName methodCategory sourceCode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassMethodRemovedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:45'!
classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode
	^self new classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode.! !

!ClassMethodRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:57'!
evento
	^'ClassMethodRemoved'! !

!ClassMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 18:16'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		((self classAffected = unChange classAffected and:
		self	 methodCategory = unChange methodCategory) and: 
		self methodName = unChange methodName) and: 
		self sourceCode = unChange sourceCode
	).! !

!ClassMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:31'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassMethodRemovedChange: self with: aRegistroDeCambio.! !

!ClassMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:44'!
classAffected
	^ classAffected! !

!ClassMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:44'!
classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode
	classAffected := aClassName.
	methodName := aMethodName.
	methodCategory := aProtocol.
	sourceCode := aSourceCode. ! !

!ClassMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:44'!
methodCategory
	^ methodCategory! !

!ClassMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:44'!
methodName
	^ methodName! !

!ClassMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:44'!
sourceCode
	^ sourceCode! !

Change subclass: #ClassRecategorizedChange
	instanceVariableNames: 'classRecategorized oldCategory newCategory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassRecategorizedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:41'!
classRecategorized: aClassName oldCategory: oldCategoryName newCategory: newCategoryName
	^self new classRecategorized: aClassName oldCategory: oldCategoryName newCategory: newCategoryName.! !

!ClassRecategorizedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:57'!
evento
	^'ClassRecategorized'! !

!ClassRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 22:33'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classRecategorized = unChange classRecategorized and:
		(self oldCategory = unChange oldCategory and:
		self	 newCategory = unChange newCategory)
	).! !

!ClassRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:21'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassRecategorizedChange: self with: aRegistroDeCambio.! !

!ClassRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:29'!
classRecategorized
	^ classRecategorized! !

!ClassRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:45'!
classRecategorized: aClassName oldCategory: oldCategoryName newCategory: newCategoryName
	classRecategorized := aClassName.
	oldCategory := oldCategoryName.
	newCategory := newCategoryName.! !

!ClassRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:29'!
newCategory
	^ newCategory! !

!ClassRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:29'!
oldCategory
	^ oldCategory! !

Change subclass: #ClassRemovedChange
	instanceVariableNames: 'classRemoved classCategory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassRemovedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:18'!
class: aClassName category: aCategoryName
	^self new classRemoved: aClassName classCategory: aCategoryName.! !

!ClassRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:57'!
evento
	^'ClassRemoved'! !

!ClassRemovedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 23:38'!
= unChange

	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		(self classRemoved = unChange classRemoved) and:
		(self classCategory = unChange classCategory)
	).! !

!ClassRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:21'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassRemovedChange: self with: aRegistroDeCambio.! !

!ClassRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:19'!
classCategory
	^ classCategory! !

!ClassRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:19'!
classRemoved
	^ classRemoved! !

!ClassRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:40'!
classRemoved: aClassName  classCategory: aCategoryName 
	classRemoved := aClassName.
	classCategory := aCategoryName.! !

Change subclass: #ClassVariableCreatedChange
	instanceVariableNames: 'classAffected variableName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassVariableCreatedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:16'!
classAffected: aClassName variableName: aVariableName
	^self new classAffected: aClassName variableName: aVariableName.! !

!ClassVariableCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:58'!
evento
	^'ClassVariableCreated'! !

!ClassVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 21:40'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classAffected = unChange classAffected and:
		self	 variableName = unChange variableName
	).! !

!ClassVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:21'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassVariableCreatedChange: self with: aRegistroDeCambio.! !

!ClassVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:15'!
classAffected
	^ classAffected! !

!ClassVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:15'!
classAffected: aClassName variableName: aVariableName
	classAffected := aClassName.
	variableName := aVariableName.
	! !

!ClassVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:15'!
variableName
	^ variableName! !

Change subclass: #ClassVariableRemovedChange
	instanceVariableNames: 'classAffected variableName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ClassVariableRemovedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:19'!
classAffected: aClassName variableName: aVariableName
	^self new classAffected: aClassName variableName: aVariableName.! !

!ClassVariableRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:58'!
evento
	^'ClassVariableRemoved'! !

!ClassVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 21:40'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classAffected = unChange classAffected and:
		self	 variableName = unChange variableName
	).! !

!ClassVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:22'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitClassVariableRemovedChange: self with: aRegistroDeCambio.! !

!ClassVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:19'!
classAffected
	^ classAffected! !

!ClassVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:18'!
classAffected: aClassName variableName: aVariableName
	classAffected := aClassName.
	variableName := aVariableName.
	! !

!ClassVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 20:19'!
variableName
	^ variableName! !

Change subclass: #InstanceMethodCategoyReorganizedChange
	instanceVariableNames: 'classAffected arrayDeCategorias'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InstanceMethodCategoyReorganizedChange class methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 22:34'!
class: aClassName with: categoryArray 
	^self new initializeWithClassName: aClassName with: categoryArray.! !

!InstanceMethodCategoyReorganizedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:58'!
evento
	^'InstanceMethodCategoyReorganized'.! !

!InstanceMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 22:41'!
= unChange 
	(unChange isKindOf: self class) ifFalse:[^false].
	^ classAffected = unChange classAffected and: arrayDeCategorias = unChange arrayDeCategorias
	 ! !

!InstanceMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:22'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitInstanceMethodCategoyReorganizedChange: self with: aRegistroDeCambio.! !

!InstanceMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 22:42'!
arrayDeCategorias
	^ arrayDeCategorias! !

!InstanceMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 22:41'!
classAffected
	^ classAffected! !

!InstanceMethodCategoyReorganizedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 22:35'!
initializeWithClassName: unNombreDeClase with: unArrayDeCategorias 
	
	classAffected := unNombreDeClase.
	arrayDeCategorias := unArrayDeCategorias.! !

Change subclass: #InstanceMethodChangedChange
	instanceVariableNames: 'classAffected methodName oldSourceCode newSourceCode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InstanceMethodChangedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 19:46'!
classAffected: aClassName methodName: aMethodName oldSourceCode: anOldSource newSourceCode: aNewSource
	^self new classAffected: aClassName methodName: aMethodName oldSourceCode: anOldSource newSourceCode: aNewSource.
! !

!InstanceMethodChangedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:58'!
evento 
	^'InstanceMethodChanged'! !

!InstanceMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 19:56'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		((self classAffected = unChange classAffected and:
		self	 methodName = unChange methodName) and: 
		self newSourceCode = unChange newSourceCode) and: 
		self oldSourceCode = unChange oldSourceCode
	).! !

!InstanceMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:22'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitInstanceMethodChangedChange: self with: aRegistroDeCambio.! !

!InstanceMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:16'!
classAffected
	^classAffected! !

!InstanceMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:17'!
classAffected: aClassName methodName: aMethodName oldSourceCode: anOldSource newSourceCode: aNewSource
	classAffected := aClassName.
	methodName := aMethodName.
	oldSourceCode := anOldSource.
	newSourceCode := aNewSource. ! !

!InstanceMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:17'!
methodName
	^ methodName! !

!InstanceMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:17'!
newSourceCode
	^newSourceCode.! !

!InstanceMethodChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:17'!
oldSourceCode
	^oldSourceCode.! !

Change subclass: #InstanceMethodCreatedChange
	instanceVariableNames: 'classAffected methodName methodCategory sourceCode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InstanceMethodCreatedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:18'!
classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode
	^self new classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode.! !

!InstanceMethodCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:59'!
evento
	^'InstanceMethodCreated'! !

!InstanceMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 18:15'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		((self classAffected = unChange classAffected and:
		self	 methodCategory = unChange methodCategory) and: 
		self methodName = unChange methodName) and: 
		self sourceCode = unChange sourceCode
	).! !

!InstanceMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:22'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitInstanceMethodCreatedChange: self with: aRegistroDeCambio.! !

!InstanceMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:18'!
classAffected
	^ classAffected! !

!InstanceMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:18'!
classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode
	classAffected := aClassName.
	methodName := aMethodName.
	methodCategory := aProtocol.
	sourceCode := aSourceCode. ! !

!InstanceMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:19'!
methodCategory
	^ methodCategory! !

!InstanceMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:18'!
methodName
	^ methodName! !

!InstanceMethodCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:19'!
sourceCode
	^ sourceCode! !

Change subclass: #InstanceMethodRecategorizedChange
	instanceVariableNames: 'classAffected methodName oldMethodCategory newMethodCategory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InstanceMethodRecategorizedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:19'!
classAffected: aClassName methodName: aMethodName oldMethodCategory: aProtocol newMethodCategory: aNewProtocol
	^self new classAffected: aClassName methodName: aMethodName oldMethodCategory: aProtocol newMethodCategory: aNewProtocol.! !

!InstanceMethodRecategorizedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:59'!
evento
	^'InstanceMethodRecategorized'! !

!InstanceMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 19:09'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		(self classAffected = unChange classAffected and:
		self	 methodName = unChange methodName) and:
		(self newMethodCategory = unChange newMethodCategory and: 
		self oldMethodCategory = unChange oldMethodCategory)
	).! !

!InstanceMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:22'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitInstanceMethodRecategorizedChange: self with: aRegistroDeCambio.! !

!InstanceMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:19'!
classAffected
	^ classAffected! !

!InstanceMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:19'!
classAffected: aClassName methodName: aMethodName oldMethodCategory: aProtocol newMethodCategory: aNewProtocol
	classAffected := aClassName.
	methodName := aMethodName.
	oldMethodCategory := aProtocol.
	newMethodCategory := aNewProtocol. ! !

!InstanceMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:19'!
methodName
	^ methodName! !

!InstanceMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:19'!
newMethodCategory
	^ newMethodCategory! !

!InstanceMethodRecategorizedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:19'!
oldMethodCategory
	^ oldMethodCategory! !

Change subclass: #InstanceMethodRemovedChange
	instanceVariableNames: 'methodName methodCategory sourceCode classAffected'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InstanceMethodRemovedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:24'!
classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode
	^self new classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode.! !

!InstanceMethodRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:59'!
evento
	^'InstanceMethodRemoved'! !

!InstanceMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/20/2013 18:15'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		((self classAffected = unChange classAffected and:
		self	 methodCategory = unChange methodCategory) and: 
		self methodName = unChange methodName) and: 
		self sourceCode = unChange sourceCode
	).! !

!InstanceMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:22'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitInstanceMethodRemovedChange: self with: aRegistroDeCambio.! !

!InstanceMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:26'!
classAffected
	^ classAffected! !

!InstanceMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:26'!
classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode
	classAffected := aClassName.
	methodName := aMethodName.
	methodCategory := aProtocol.
	sourceCode := aSourceCode. ! !

!InstanceMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:26'!
methodCategory
	^ methodCategory! !

!InstanceMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:26'!
methodName
	^ methodName! !

!InstanceMethodRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 21:26'!
sourceCode
	^ sourceCode! !

Change subclass: #InstanceVariableCreatedChange
	instanceVariableNames: 'classAffected variableName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InstanceVariableCreatedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:21'!
classAffected: aClassName variableName: aVariableName
	^self new classAffected: aClassName variableName: aVariableName.
	! !

!InstanceVariableCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:59'!
evento
	^'InstanceVariableCreated'! !

!InstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 21:37'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classAffected = unChange classAffected and:
		self	 variableName = unChange variableName
	).! !

!InstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:22'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitInstanceVariableCreatedChange: self with: aRegistroDeCambio.! !

!InstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:21'!
classAffected
	^ classAffected! !

!InstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:48'!
classAffected: aClassName variableName: aVariableName
	classAffected := aClassName.
	variableName := aVariableName.
	! !

!InstanceVariableCreatedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:26'!
variableName
	^variableName.! !

Change subclass: #InstanceVariableRemovedChange
	instanceVariableNames: 'classAffected variableName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InstanceVariableRemovedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:25'!
classAffected: aClassName variableName: aVariableName
	^self new  classAffected: aClassName variableName: aVariableName.! !

!InstanceVariableRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:59'!
evento
	^'InstanceVariableRemoved'! !

!InstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 21:37'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classAffected = unChange classAffected and:
		self	 variableName = unChange variableName
	).! !

!InstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:22'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitInstanceVariableRemovedChange: self with: aRegistroDeCambio.! !

!InstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:25'!
classAffected
	^ classAffected! !

!InstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:48'!
classAffected: aClassName variableName: aVariableName
	classAffected := aClassName.
	variableName := aVariableName.
	! !

!InstanceVariableRemovedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:26'!
variableName
	^variableName.! !

Change subclass: #PoolDictionaryCreatedChange
	instanceVariableNames: 'classAffected poolDictionaryName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!PoolDictionaryCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 17:57'!
classAffected: aClassName poolDictionaryName: aPoolDictionaryName 
	
	^self new classAffected: aClassName poolDictionaryName: aPoolDictionaryName.! !

!PoolDictionaryCreatedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 13:00'!
evento
	^'PoolDictionaryCreated'! !

!PoolDictionaryCreatedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 19:02'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classAffected = unChange classAffected and:
		self	 poolDictionaryName = unChange poolDictionaryName
	).! !

!PoolDictionaryCreatedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 12:18'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitPoolDictionaryCreatedChange: self with: aRegistroDeCambio.! !

!PoolDictionaryCreatedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 19:02'!
classAffected
	^ classAffected! !

!PoolDictionaryCreatedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 17:59'!
classAffected: aClassName poolDictionaryName: aPoolDictionaryName 
	
	classAffected := aClassName.
	poolDictionaryName := aPoolDictionaryName.! !

!PoolDictionaryCreatedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 19:03'!
poolDictionaryName
	^ poolDictionaryName! !

Change subclass: #PoolDictionaryRemovedChange
	instanceVariableNames: 'classAffected poolDictionaryName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!PoolDictionaryRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 18:16'!
classAffected: aClassName poolDictionaryName: aPoolDictionaryName
	^self new classAffected: aClassName poolDictionaryName: aPoolDictionaryName.! !

!PoolDictionaryRemovedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 13:00'!
evento
	^'PoolDictionaryRemoved'! !

!PoolDictionaryRemovedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 19:11'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		self classAffected = unChange classAffected and:
		self	 poolDictionaryName = unChange poolDictionaryName
	).! !

!PoolDictionaryRemovedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 12:19'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitPoolDictionaryRemovedChange: self with: aRegistroDeCambio.! !

!PoolDictionaryRemovedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 19:12'!
classAffected
	
	^ classAffected! !

!PoolDictionaryRemovedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 18:17'!
classAffected: aClassName poolDictionaryName: aPoolDictionaryName 
	
	classAffected := aClassName.
	poolDictionaryName := aPoolDictionaryName.! !

!PoolDictionaryRemovedChange methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 19:12'!
poolDictionaryName
	
	^ poolDictionaryName! !

Change subclass: #SuperclassChangedChange
	instanceVariableNames: 'classAffected oldSuperclass newSuperclass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!SuperclassChangedChange class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:44'!
classAffected: aClassName oldSuperclass: aSuperClassName newSuperclass: aSuperClassName2
	^self new classAffected: aClassName oldSuperclass: aSuperClassName newSuperclass: aSuperClassName2.! !

!SuperclassChangedChange class methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 13:00'!
evento
	^'SuperClassChanged'! !

!SuperclassChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/19/2013 22:55'!
= unChange
	(unChange isKindOf: self class) ifFalse:[^false].
	^(
		(self classAffected = unChange classAffected and:
		self	 newSuperclass = unChange newSuperclass) and:
		self oldSuperclass = unChange oldSuperclass 
	).! !

!SuperclassChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:23'!
accept: aVisitor return: aRegistroDeCambio 
	^aVisitor visitSuperclassChangedChange: self with: aRegistroDeCambio.! !

!SuperclassChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:45'!
classAffected
	^ classAffected! !

!SuperclassChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 19:47'!
classAffected: aClassName oldSuperclass: oldSuperclassName newSuperclass: newSuperclassName
	classAffected := aClassName.
	oldSuperclass := oldSuperclassName.
	newSuperclass := newSuperclassName.
	! !

!SuperclassChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:46'!
newSuperclass
	^ newSuperclass! !

!SuperclassChangedChange methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/13/2013 18:46'!
oldSuperclass
	^ oldSuperclass! !

Object subclass: #InterfazDeEntradaDelSistemaDeCambios
	instanceVariableNames: 'sistemaDeCambios autor reloj local'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InterfazDeEntradaDelSistemaDeCambios class methodsFor: 'as yet unclassified' stamp: 'SebaServer 12/3/2013 23:43'!
newWith: unSistemaDeCambios andThisAuthor: unAutor andThisClock: unReloj 
	^self new initializeWith: unSistemaDeCambios andThisAuthor: unAutor andThisClock: unReloj.! !

!InterfazDeEntradaDelSistemaDeCambios class methodsFor: 'as yet unclassified' stamp: 'SebaServer 12/4/2013 00:03'!
remotoWith: unSistemaDeCambios andThisAuthor: unAutor andThisClock: unReloj 
	^(self newWith: unSistemaDeCambios andThisAuthor: unAutor andThisClock: unReloj) remoto.! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 9/29/2013 17:52'!
agregarCambio: unCambio por: unNombreDeAutor enElMomento: unaFechaYHora 

	sistemaDeCambios registrarCambio: (RegistroDeCambio newWithThischange: unCambio andThisAuthor: unNombreDeAutor atThisTime: unaFechaYHora ).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebaServer 12/4/2013 01:51'!
classCategoryCreated: aByteSymbol
	self handle: (ClassCategoryCreatedChange categoryName: aByteSymbol)! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 18:58'!
classCategoryRemoved: aByteSymbol 
	self handle: (ClassCategoryRemovedChange categoryName: aByteSymbol)! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 19:04'!
classCategoryRenamedFrom: aByteSymbol to: aByteSymbol2 
	self handle: (ClassCategoryRenamedChange from: aByteSymbol to: aByteSymbol2 ).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/19/2013 20:21'!
classCreated: aClassName inCategory: aCategoryName superclass: aSuperclassName
	self handle: (ClassCreatedChange class: aClassName category: aCategoryName superclass: aSuperclassName).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 19:32'!
classInstanceVariableCreatedOn: aClassName named: aVariableName 
	self handle: (ClassInstanceVariableCreatedChange classAffected: aClassName variableName: aVariableName).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 19:55'!
classInstanceVariableRemovedFrom: aClassName named: aVariableName
	self handle: (ClassInstanceVariableRemovedChange classAffected: aClassName variableName: aVariableName).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 20:33'!
classMethod: aMethodName createdOn: aClassName inCategory: aProtocol withCode: aSourceCode
	self handle: (ClassMethodCreatedChange classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 20:52'!
classMethod: aMethodName onClass: aClassName recategorizedFrom: aProtocol to: aNewProtocol
	self handle: (ClassMethodRecategorizedChange classAffected: aClassName methodName: aMethodName oldMethodCategory: aProtocol newMethodCategory: aNewProtocol).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 20:46'!
classMethod: aMethodName removedFrom: aClassName inCategory: aProtocol withCode: aSourceCode
	self handle: (ClassMethodRemovedChange classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 23:17'!
classMethodCategoyReorganized: aClassName categories: unArrayDeCategorias 
	self handle: ( ClassMethodCategoyReorganizedChange class: aClassName with: unArrayDeCategorias ) .! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/20/2013 19:48'!
classMethodChanged: aMethodName onClass: aClassName oldSourceCode: anOldSourceCode newSourceCode: aNewSourceCode
	self handle: (ClassMethodChangedChange classAffected: aClassName methodName: aMethodName oldSourceCode: anOldSourceCode newSourceCode: aNewSourceCode).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 20:14'!
classRecategorized: aClassName fromCategory: aCategory toCategory: anotherCategory
	self handle: (ClassRecategorizedChange classRecategorized: aClassName oldCategory: aCategory newCategory: anotherCategory).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 20:14'!
classRemoved: aClassName fromCategory: aCategoryName
	self handle: (ClassRemovedChange class: aClassName category: aCategoryName).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 20:17'!
classVariableCreatedOn: aClassName named: aVariableName 
	self handle: (ClassVariableCreatedChange classAffected: aClassName variableName: aVariableName).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 20:18'!
classVariableRemovedFrom: aClassName named: aVariableName 
	self handle: (ClassVariableRemovedChange classAffected: aClassName variableName: aVariableName).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'handling' stamp: 'SebaServer 12/4/2013 00:00'!
handle: unCambio
	local
		ifTrue: [ self agregarCambio: unCambio por: autor fullName enElMomento: reloj now.]
		ifFalse: [ self agregarCambio: unCambio por: autor enElMomento: reloj. ]
! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'initialize-release' stamp: 'SebaServer 12/4/2013 00:01'!
initializeWith: unSistemaDeCambios andThisAuthor: unAutor andThisClock: unReloj
	sistemaDeCambios := unSistemaDeCambios.
	autor := unAutor.
	reloj := unReloj.
	local := true.! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 21:21'!
instanceMethod: aMethodName createdOn: aClassName inCategory: aProtocol withCode: aSourceCode
	self handle: (InstanceMethodCreatedChange classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 21:21'!
instanceMethod: aMethodName onClass: aClassName recategorizedFrom: aProtocol to: aNewProtocol
	self handle: (InstanceMethodRecategorizedChange classAffected: aClassName methodName: aMethodName oldMethodCategory: aProtocol newMethodCategory: aNewProtocol).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 21:25'!
instanceMethod: aMethodName removedFrom: aClassName inCategory: aProtocol withCode: aSourceCode
	self handle: (InstanceMethodRemovedChange classAffected: aClassName methodName: aMethodName methodCategory: aProtocol sourceCode: aSourceCode).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 10/31/2013 22:32'!
instanceMethodCategoyReorganized: aClassName categories: categoryArray 
	self handle: ( InstanceMethodCategoyReorganizedChange class: aClassName with: categoryArray ) .! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 21:23'!
instanceMethodChanged: aMethodName onClass: aClassName oldSourceCode: anOldSourceCode newSourceCode: aNewSourceCode
	self handle: (InstanceMethodChangedChange classAffected: aClassName methodName: aMethodName oldSourceCode: anOldSourceCode newSourceCode: aNewSourceCode). ! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 19:20'!
instanceVariableCreatedOn: aByteSymbol named: aByteSymbol2 
	self handle: (InstanceVariableCreatedChange classAffected: aByteSymbol variableName: aByteSymbol2 ).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 19:24'!
instanceVariableRemovedFrom: aClassName named: aVariableName
	self handle: (InstanceVariableRemovedChange classAffected: aClassName variableName: aVariableName )! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 17:38'!
poolDictionaryCreatedOn: aClassName named: aPoolDictionaryName 
	self handle: ( PoolDictionaryCreatedChange classAffected: aClassName poolDictionaryName: aPoolDictionaryName ).! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 11/9/2013 18:14'!
poolDictionaryRemovedFrom: aClassName named: aPoolDictionaryName 
	self handle: ( PoolDictionaryRemovedChange classAffected: aClassName poolDictionaryName: aPoolDictionaryName ).
	! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebaServer 12/4/2013 00:26'!
remoto
	local := false.! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'accessing' stamp: 'SebastinGarbi 9/29/2013 19:39'!
sistemaDeCambios
	^ sistemaDeCambios! !

!InterfazDeEntradaDelSistemaDeCambios methodsFor: 'Changes' stamp: 'SebastianGarbi 10/13/2013 18:44'!
superclassChangedOn: aClassName from: aSuperClassName to: aSuperClassName2
	self handle: (SuperclassChangedChange classAffected: aClassName oldSuperclass: aSuperClassName newSuperclass: aSuperClassName2).! !

Object subclass: #InterfazDeEntradaWeb
	instanceVariableNames: 'sistemaDeCambios vista modeloADibujar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InterfazDeEntradaWeb class methodsFor: 'as yet unclassified' stamp: 'Maxii 10/19/2013 18:01'!
new: unSistemaDeCambios 

	^self new initializeWith: unSistemaDeCambios. ! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 17:15'!
agregarOQuitarUDT: idDeUnidadDeTrabajo ok: aBoolean 
	( sistemaDeCambios idsDeUnidadesDeTrabajo includes: idDeUnidadDeTrabajo ) ifFalse: [ Error signal: 'El Id no corresponde a una unidad de trabajo.' ].
	modeloADibujar setearUnidad: idDeUnidadDeTrabajo con: aBoolean. ! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 20:25'!
agregarOQuitarUDTActiva: aBoolean
	aBoolean
		ifTrue: [ self armarModeloAgregandoUnidadActiva]
		ifFalse: [ self armarModeloQuitandoUnidadActiva ].
! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 14:27'!
armarAgregandoOQuitando: unObjeto 
	modeloADibujar agregarOQuitarElementoAMostrar: unObjeto.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 00:20'!
armarModeloAgregandoUnidadActiva
	modeloADibujar agregarUnidadActiva.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 21:05'!
armarModeloQuitandoUnidadActiva
	
	modeloADibujar quitarUnidadActiva.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 21:18'!
cambiosCategorizadosPorElementoDeLasUnidadesSeleccionadas
	| categorizador cambios |
	categorizador := CategorizadorDeChanges new.
	cambios:= modeloADibujar unidadesCerradasAUsar inject: OrderedCollection new into: [ :resultado :unElemento | 
		resultado addAll: (sistemaDeCambios todosLosCambiosDe: unElemento);yourself
	 ].
	modeloADibujar usarUnidadActiva ifTrue: [ cambios addAll: sistemaDeCambios todosLosCambiosDeLaUnidadActiva ].
	cambios sort: [ :registro1 :registro2 | registro1 fechaYHora <= registro2 fechaYHora ].
	^categorizador categorizar: cambios.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:48'!
cambiosParaTddVsTesting
	| tdd |
	tdd := TDDVsTestingVisitor for: sistemaDeCambios.
	^tdd value.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/24/2013 18:01'!
dibujarEn: html 
	vista dibujarEn: html.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 12:11'!
generarVistaArbolDeEstadisticas
	vista := VistaArbolDeEstadisticas newWithThisInterfazWeb: self  andThisModel: modeloADibujar andThisSistemaDeCambios: sistemaDeCambios.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 18:29'!
generarVistaArbolPorCategoriaDeElemento
		vista := VistaArbolDeCategoria newWithThisInterfazWeb: self andThisModel: modeloADibujar andThisSistemaDeCambios: sistemaDeCambios.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 18:33'!
generarVistaArbolPorUnidadDeTrabajo
	vista := VistaAgrupadoPorUnidadDeTrabajo newWithThisInterfazWeb: self andThisModel: modeloADibujar andThisSistemaDeCambios: sistemaDeCambios.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 20:37'!
generarVistaCronologica
	vista := VistaCronologica newWithThisInterfazWeb: self andThisModelo: modeloADibujar andThisSistemaDeCambios: sistemaDeCambios.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 11/3/2013 19:50'!
generarVistaHotSpot
	vista := VistaHotSpot newWithThisInterfazWeb: self  andThisModel: modeloADibujar andThisSistemaDeCambios: sistemaDeCambios.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:43'!
generarVistaTDDVsTesting
	vista := VistaTddVsTesting newWithThisInterfazWeb: self andThisModel: modeloADibujar andThisSistemaDeCambios: sistemaDeCambios.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 18:43'!
initializeWith: unSistemaDeCambios 
	sistemaDeCambios := unSistemaDeCambios.
	modeloADibujar := ModeloADibujar new.
	vista := VistaDePresentacion newWithThisInterfazWeb: self andThisModelo: modeloADibujar andThisSistemaDeCambios: sistemaDeCambios.
	! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 00:20'!
modeloADibujar
	
	^ modeloADibujar! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 00:20'!
resetModelo

	modeloADibujar := ModeloADibujar new.! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 12:38'!
sistemaDeCambios
	^sistemaDeCambios .! !

!InterfazDeEntradaWeb methodsFor: 'as yet unclassified' stamp: 'Maxii 10/23/2013 23:08'!
vista
	^vista.! !

Object subclass: #InterfazDeUsuario
	instanceVariableNames: 'sistemaDeCambios'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!InterfazDeUsuario class methodsFor: 'as yet unclassified' stamp: 'Maxiii 9/30/2013 13:09'!
newWith: unSistemaDeCambios 
	^self new initializeWith: unSistemaDeCambios.! !

!InterfazDeUsuario methodsFor: 'as yet unclassified' stamp: 'Maxiii 9/30/2013 13:11'!
cerrarUnidad
	sistemaDeCambios cerrarUnidadDeTrabajoActiva.! !

!InterfazDeUsuario methodsFor: 'as yet unclassified' stamp: 'Maxiii 9/30/2013 13:09'!
initializeWith: unSistemaDeCambios 
	sistemaDeCambios := unSistemaDeCambios.! !

!InterfazDeUsuario methodsFor: 'as yet unclassified' stamp: 'Maxiii 9/30/2013 13:41'!
todosLosCambios
	^sistemaDeCambios todosLosCambios.! !

!InterfazDeUsuario methodsFor: 'as yet unclassified' stamp: 'Maxiii 9/30/2013 13:45'!
todosLosCambiosDelMensajeDeClase: aSelector deLaClase: aClass 
	^sistemaDeCambios historiaDelMetodoDeClase: aSelector deLaClase: aClass .! !

!InterfazDeUsuario methodsFor: 'as yet unclassified' stamp: 'Maxiii 9/30/2013 14:05'!
todosLosCambiosDelMensajeDeInstancia: aSelector deLaClase: aClass 
	^sistemaDeCambios historiaDelMetodoDeInstancia: aSelector deLaClase: aClass.! !

Object subclass: #ModeloADibujar
	instanceVariableNames: 'unidadesCerradasAUsar usarUnidadActiva elementosAMostrar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 15:45'!
agregarIdDeUnidadCerrada: unId 
	unidadesCerradasAUsar at: unId put: true.
	"unidadesCerradasAUsar add: unId."! !

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 21:46'!
agregarOQuitarElementoAMostrar: unObjeto 
	elementosAMostrar remove: unObjeto ifAbsent: [ elementosAMostrar add: unObjeto ].! !

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 10/28/2013 21:49'!
agregarUnidadActiva
	usarUnidadActiva := true.! !

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 12:08'!
elementosAMostrar
	^elementosAMostrar.! !

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 20:02'!
initialize 
	unidadesCerradasAUsar := Dictionary new.
	usarUnidadActiva := false.
	elementosAMostrar := OrderedCollection new.! !

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 20:58'!
quitarUnidadActiva
	usarUnidadActiva := false.! !

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 20:01'!
setearUnidad: aSmallInteger con:  aBoolean 
	unidadesCerradasAUsar at: aSmallInteger put: aBoolean.! !

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 20:07'!
unidadesCerradasAUsar
	
	^unidadesCerradasAUsar keys select: [ :id | unidadesCerradasAUsar at: id].! !

!ModeloADibujar methodsFor: 'as yet unclassified' stamp: 'Maxii 10/28/2013 21:51'!
usarUnidadActiva
	
	^ usarUnidadActiva! !

Object subclass: #RegistroDeCambio
	instanceVariableNames: 'cambio autor fechaYHora'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!RegistroDeCambio class methodsFor: 'as yet unclassified' stamp: 'Maxii 9/29/2013 17:54'!
newWithThischange: unCambio andThisAuthor: unNombreDeAutor atThisTime: unaFechaYHora 
	^self new initializeWithThischange: unCambio andThisAuthor: unNombreDeAutor atThisTime: unaFechaYHora.! !

!RegistroDeCambio methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:10'!
accept: aVisitor
	^cambio accept: aVisitor return: self.! !

!RegistroDeCambio methodsFor: 'as yet unclassified' stamp: 'Maxii 9/29/2013 17:56'!
autor
	^ autor! !

!RegistroDeCambio methodsFor: 'as yet unclassified' stamp: 'Maxii 9/29/2013 18:04'!
cambio
	^ cambio! !

!RegistroDeCambio methodsFor: 'as yet unclassified' stamp: 'Maxii 9/29/2013 17:56'!
fechaYHora
	^ fechaYHora! !

!RegistroDeCambio methodsFor: 'as yet unclassified' stamp: 'Maxii 9/29/2013 17:58'!
initializeWithThischange: unCambio andThisAuthor: unNombreDeAutor atThisTime: unaFechaYHora 
	cambio := unCambio.
	autor := unNombreDeAutor.
	fechaYHora := unaFechaYHora.! !

!RegistroDeCambio methodsFor: 'as yet unclassified' stamp: 'SebastinGarbi 9/29/2013 19:18'!
tipoDeCambio
	^'classRemoved'.! !

Object subclass: #SistemaDeCambios
	instanceVariableNames: 'unidadesDeTrabajoCerradas unidadDeTrabajoActiva nuevoID'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 10/16/2013 19:13'!
cerrarUnidadDeTrabajoActiva
	
	| idDeLaUnidadCerrada |
	unidadDeTrabajoActiva cerrar.
	idDeLaUnidadCerrada := nuevoID.
	unidadesDeTrabajoCerradas at: idDeLaUnidadCerrada put: unidadDeTrabajoActiva.
	nuevoID := nuevoID + 1.
	^idDeLaUnidadCerrada.! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:55'!
historiaDelMetodoDeClase: aSelector deLaClase: aClass 
	| historial |
	historial := HistorialDeMetodoDeClase paraElMetodo: aSelector enLaClase: aClass conElSistemaDeCambios: self.
	^historial obtener.
"		summary := AccountSummary for: aReceptiveAccount.
	^ summary lines
"
"	^self todosLosCambios
		select: [ :unRegistroDeCambio | unRegistroDeCambio cambio esCambioDeMensajeDeClase: aSelector deLaClase: aClass ]"! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:56'!
historiaDelMetodoDeInstancia: aSelector deLaClase: aClass
	| historial |
	historial := HistorialDeMetodoDeInstancia paraElMetodo: aSelector enLaClase: aClass conElSistemaDeCambios: self.
	^historial obtener.
"	^ self todosLosCambios
		select: [ :unRegistroDeCambio | unRegistroDeCambio cambio esCambioDeMensajeDeInstancia: aSelector deLaClase: aClass ]"! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/26/2013 22:44'!
idActual
	^-1! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 10/18/2013 12:17'!
idsDeUnidadesDeTrabajo
	^unidadesDeTrabajoCerradas keys.! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 10/8/2013 12:22'!
initialize 
	unidadesDeTrabajoCerradas := Dictionary new.
	unidadDeTrabajoActiva := UnidadDeTrabajoInicial new.
	nuevoID := 0.! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxi 12/06/2013 12:28'!
registrarCambio: unCambio
	| nuevaUnidadActiva |
	
	[ unidadDeTrabajoActiva registrarCambio: unCambio]
		on: UnidadDeTrabajoException
		do: [ :unError | 
			nuevaUnidadActiva := UnidadDeTrabajoReal newWith: unidadDeTrabajoActiva.
			unidadDeTrabajoActiva := nuevaUnidadActiva.
			unidadDeTrabajoActiva registrarCambio: unCambio ].
! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 9/27/2013 15:10'!
todosLosCambios
	^self unidadActiva todosLosCambios.! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 10/26/2013 22:57'!
todosLosCambiosDe: idDeUnidadDeTrabajo 
	| unidadDeTrabajo |
	unidadDeTrabajo := unidadesDeTrabajoCerradas 	at: idDeUnidadDeTrabajo 
														ifAbsent: [ 
															idDeUnidadDeTrabajo = -1 ifTrue: [^self unidadActiva todosLosCambiosPropios  ] 
															ifFalse:[ self error: 'El id no corresponde a una unidad de trabajo cerrada'].
														].
														
	^unidadDeTrabajo todosLosCambiosPropios.! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 20:51'!
todosLosCambiosDeLaUnidadActiva 
	
	self unidadActiva estaCerrada ifFalse: [ ^self unidadActiva todosLosCambiosPropios ].
	^OrderedCollection new.! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 10/26/2013 19:02'!
unidadActiva
	"devuelve la unidad de trabajo activa"

	^unidadDeTrabajoActiva! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'Maxii 10/26/2013 18:50'!
unidadesCerradas
	"devuelve la unidad de trabajo cerrada"
	^Dictionary newFrom: unidadesDeTrabajoCerradas.
	! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'maxi 9/9/2013 20:43'!
unidadesDeTrabajo
	|todasLasUnidadesDeTrabajo|
	todasLasUnidadesDeTrabajo := unidadesDeTrabajoCerradas asSet.
	todasLasUnidadesDeTrabajo add: unidadDeTrabajoActiva.
	^todasLasUnidadesDeTrabajo.! !

!SistemaDeCambios methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:08'!
visitChangesWith: aHistorialDeMetodoDeClase 

	self todosLosCambios do: [ :unRegistroDeCambio | unRegistroDeCambio accept: aHistorialDeMetodoDeClase ].! !

Object subclass: #SistemaDeCambiosVisitor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

SistemaDeCambiosVisitor subclass: #HistorialDeMetodo
	instanceVariableNames: 'selector clase sistemaDeCambios historial'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!HistorialDeMetodo class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:00'!
paraElMetodo: aByteString enLaClase: aByteString2 conElSistemaDeCambios: aSistemaDeCambios 
	^self new initializeParaElMetodo: aByteString enLaClase: aByteString2 conElSistemaDeCambios: aSistemaDeCambios.! !

!HistorialDeMetodo methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:27'!
agregar: aRegistroDeCambio siCumple: aClassMethodCreatedChange
	(aClassMethodCreatedChange classAffected = clase and: aClassMethodCreatedChange methodName = selector)
		ifTrue: [ historial add: aRegistroDeCambio ]! !

!HistorialDeMetodo methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:01'!
initializeParaElMetodo: aSelector enLaClase: aClass conElSistemaDeCambios: aSistemaDeCambios 
	selector := aSelector.
	clase := aClass.
	sistemaDeCambios := aSistemaDeCambios.
	^self! !

!HistorialDeMetodo methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 16:06'!
obtener
	historial := OrderedCollection new.
	
	sistemaDeCambios visitChangesWith: self.
	
	^historial.! !

HistorialDeMetodo subclass: #HistorialDeMetodoDeClase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!HistorialDeMetodoDeClase methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:29'!
visitClassMethodChangedChange: aClassMethodChangedChange with: aRegistroDeCambio 
	self agregar: aRegistroDeCambio  siCumple: aClassMethodChangedChange.! !

!HistorialDeMetodoDeClase methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:30'!
visitClassMethodCreatedChange: aClassMethodCreatedChange with: aRegistroDeCambio
	self agregar: aRegistroDeCambio siCumple: aClassMethodCreatedChange! !

!HistorialDeMetodoDeClase methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:30'!
visitClassMethodRecategorizedChange: aClassMethodRecategorizedChange with: aRegistroDeCambio 
	self agregar: aRegistroDeCambio siCumple: aClassMethodRecategorizedChange.! !

!HistorialDeMetodoDeClase methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:31'!
visitClassMethodRemovedChange: aClassMethodRemovedChange with: aRegistroDeCambio 
	self agregar: aRegistroDeCambio siCumple: aClassMethodRemovedChange.! !

HistorialDeMetodo subclass: #HistorialDeMetodoDeInstancia
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!HistorialDeMetodoDeInstancia methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:27'!
visitInstanceMethodChangedChange: anInstanceMethodChangedChange with: aRegistroDeCambio 
	self agregar: aRegistroDeCambio siCumple: anInstanceMethodChangedChange .! !

!HistorialDeMetodoDeInstancia methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:28'!
visitInstanceMethodCreatedChange: aChange with: aRegistroDeCambio 
	self agregar: aRegistroDeCambio siCumple: aChange.
	
	! !

!HistorialDeMetodoDeInstancia methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:28'!
visitInstanceMethodRecategorizedChange: anInstanceMethodRecategorizedChange with: aRegistroDeCambio 
	self agregar: aRegistroDeCambio siCumple: anInstanceMethodRecategorizedChange.! !

!HistorialDeMetodoDeInstancia methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:28'!
visitInstanceMethodRemovedChange: anInstanceMethodRemovedChange with: aRegistroDeCambio 
	self agregar: aRegistroDeCambio siCumple: anInstanceMethodRemovedChange.! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:45'!
visitClassCategoryCreatedChange: aClassCategoryCreatedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:48'!
visitClassCategoryRemovedChange: aClassCategoryRemovedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:49'!
visitClassCategoryRenamedChange: aClassCategoryRenamedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:48'!
visitClassCreatedChange: aClassCreatedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassInstanceVariableCreatedChange: aClassInstanceVariableCreatedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassInstanceVariableRemovedChange: aClassInstanceVariableRemovedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassMethodCategoyReorganizedChange: aClassMethodCategoyReorganizedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassMethodChangedChange: aClassMethodChangedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassMethodCreatedChange: aClassMethodCreatedChange with: aRegistroDeCambio ! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassMethodRecategorizedChange: aClassMethodRecategorizedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassMethodRemovedChange: aClassMethodRemovedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassRecategorizedChange: aClassRecategorizedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:47'!
visitClassRemovedChange: aClassRemovedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:47'!
visitClassVariableCreatedChange: aClassVariableCreatedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitClassVariableRemovedChange: aClassVariableRemovedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitInstanceMethodCategoyReorganizedChange: anInstanceMethodCategoyReorganizedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitInstanceMethodChangedChange: anInstanceMethodChangedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:48'!
visitInstanceMethodCreatedChange: anInstanceMethodCreatedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitInstanceMethodRecategorizedChange: anInstanceMethodRecategorizedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitInstanceMethodRemovedChange: anInstanceMethodRemovedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitInstanceVariableCreatedChange: anInstanceVariableCreatedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitInstanceVariableRemovedChange: anInstanceVariableRemovedChange with: aRegistroDeCambio 
! !

!SistemaDeCambiosVisitor methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 13:24'!
visitPoolDictionaryCreatedChange: aPoolDictionaryCreatedChange with: aRegistroDeCambio 
	! !

!SistemaDeCambiosVisitor methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 13:25'!
visitPoolDictionaryRemovedChange: aPoolDictionaryRemovedChange with: aRegistroDeCambio 
	! !

!SistemaDeCambiosVisitor methodsFor: 'visitor' stamp: 'SebastianGarbi 11/3/2013 18:46'!
visitSuperclassChangedChange: aSuperclassChangedChange with: aRegistroDeCambio 
! !

SistemaDeCambiosVisitor subclass: #TDDVsTestingVisitor
	instanceVariableNames: 'tdd testing tests noTest sistemaDeCambios'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!TDDVsTestingVisitor class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 18:39'!
for: unSistemaDeCambios
	^self new initializeFor: unSistemaDeCambios.! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:57'!
agregarChanged: aRegistroDeCambio
	(self esTest: aRegistroDeCambio)
		ifTrue: [ tests add: (
			TDDVsTestingMethod
				name: aRegistroDeCambio cambio methodName
				sourceCode: aRegistroDeCambio cambio newSourceCode
				fechaYHora: aRegistroDeCambio fechaYHora
				registro: aRegistroDeCambio) ]! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:58'!
agregarCreated: aRegistroDeCambio
	(self esTest: aRegistroDeCambio)
		ifTrue: [ tests add: (
			TDDVsTestingMethod
				name: aRegistroDeCambio cambio methodName
				sourceCode: aRegistroDeCambio cambio sourceCode
				fechaYHora: aRegistroDeCambio fechaYHora
				registro: aRegistroDeCambio) ]
		ifFalse: [noTest add: (
			TDDVsTestingMethod
				name: aRegistroDeCambio cambio methodName
				sourceCode: aRegistroDeCambio cambio sourceCode
				fechaYHora: aRegistroDeCambio fechaYHora
				registro: aRegistroDeCambio) ].! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 18:41'!
dividirMetodos
	sistemaDeCambios todosLosCambios do: [ :unCambio |
		unCambio accept: self.
	]! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:41'!
esTest: aRegistroDeCambio
	^ (aRegistroDeCambio cambio methodName findString: 'test') = 1! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:01'!
initialize
	tdd := OrderedCollection new.
	testing := OrderedCollection new.
	tests := OrderedCollection new.
	noTest := OrderedCollection new.! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 18:39'!
initializeFor: unSistemaDeCambios
	sistemaDeCambios := unSistemaDeCambios.! !

!TDDVsTestingVisitor methodsFor: 'accessing' stamp: 'SebastianGarbi 11/3/2013 18:59'!
noTest
	^ noTest! !

!TDDVsTestingVisitor methodsFor: 'accessing' stamp: 'SebastianGarbi 11/3/2013 18:59'!
tests
	^ tests! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:01'!
ubicar: aRegistroDeCambio 
	((aRegistroDeCambio cambio methodName findString: 'test') = 1) ifTrue: [ tests add: aRegistroDeCambio]
	ifFalse: [ noTest add: aRegistroDeCambio].
! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:36'!
value
	| resultado aux |
	resultado := Dictionary new at: 'TDD' put: OrderedCollection new; at: 'Testing' put: OrderedCollection new;yourself.
	
	self initialize.
	self dividirMetodos.
	
	noTest do: [ :aTddVsTestingMethod |
		aux := tests select: [ :aTest | (aTest sourceCode findString: aTddVsTestingMethod name) ~=0 ].
		(aux isEmpty) ifFalse: [
			(resultado
				at: [aux first fechaYHora < aTddVsTestingMethod fechaYHora
					ifTrue:[ 'TDD' ]
					ifFalse:['Testing']] value)
					add:(
						Dictionary new
							at: 'metodo' put: aTddVsTestingMethod registro;
							at: 'test' put: aux first registro;
							yourself
					).
				].
		].
	^resultado! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:39'!
visitClassMethodChangedChange: aClassMethodChangedChange with: aRegistroDeCambio 
	self agregarChanged: aRegistroDeCambio.
! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:42'!
visitClassMethodCreatedChange: aClassMethodCreatedChange with: aRegistroDeCambio
	self agregarCreated: aRegistroDeCambio.! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:42'!
visitInstanceMethodChangedChange: anInstanceMethodChangedChange with: aRegistroDeCambio 
	self agregarChanged: aRegistroDeCambio.! !

!TDDVsTestingVisitor methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:43'!
visitInstanceMethodCreatedChange: anInstanceMethodCreatedChange with: aRegistroDeCambio 
	self agregarCreated: aRegistroDeCambio.! !

Object subclass: #TDDVsTestingMethod
	instanceVariableNames: 'name sourceCode fechaYHora registro'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!TDDVsTestingMethod class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:49'!
name: aByteSymbol sourceCode: aByteString fechaYHora: aDateAndTime 
	^self new name: aByteSymbol sourceCode: aByteString fechaYHora: aDateAndTime.! !

!TDDVsTestingMethod class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:58'!
name: aByteSymbol sourceCode: aByteString fechaYHora: aDateAndTime registro: aRegistroDeCambio 
	^self new name: aByteSymbol sourceCode: aByteString fechaYHora: aDateAndTime registro: aRegistroDeCambio ! !

!TDDVsTestingMethod methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:02'!
fechaYHora
	^fechaYHora.! !

!TDDVsTestingMethod methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:02'!
name
	^name.! !

!TDDVsTestingMethod methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:50'!
name: aByteSymbol sourceCode: aByteString fechaYHora: aDateAndTime 
	name := aByteSymbol.
	sourceCode := aByteString.
	fechaYHora := aDateAndTime.

	! !

!TDDVsTestingMethod methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 19:59'!
name: aByteSymbol sourceCode: aByteString fechaYHora: aDateAndTime registro: aRegistroDeCambio 
	name := aByteSymbol.
	sourceCode := aByteString.
	fechaYHora := aDateAndTime.
	registro := aRegistroDeCambio.
	! !

!TDDVsTestingMethod methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:02'!
registro
	^registro.! !

!TDDVsTestingMethod methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:01'!
sourceCode
	^ sourceCode! !

Object subclass: #UnidadDeTrabajo
	instanceVariableNames: 'cambios cerrada'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

UnidadDeTrabajo class
	instanceVariableNames: 'unidadActiva unidadesCerradas'!

UnidadDeTrabajo class
	instanceVariableNames: 'unidadActiva unidadesCerradas'!

!UnidadDeTrabajo class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/16/2013 22:44'!
noSePuedeRegistrarCambios
	^'No se puede registrar cambios en esta unidad de trabajo.'.! !

!UnidadDeTrabajo class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/16/2013 23:30'!
registrarCambio: unCambio
	| nuevaUnidadActiva |
	[ unidadActiva registrarCambio: unCambio]
	on: Error
	do: [ nuevaUnidadActiva := UnidadDeTrabajoReal newWith: unidadActiva.
		unidadesCerradas add: unidadActiva.
		unidadActiva := nuevaUnidadActiva.
		unidadActiva registrarCambio: unCambio ].
	^self
! !

!UnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/16/2013 22:44'!
cerrar
	cerrada := true.! !

!UnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/16/2013 22:44'!
estaCerrada
	^cerrada.! !

!UnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'Maxii 9/30/2013 10:31'!
historiaCompletaDe: aSelector 
	self subclassResponsibility.! !

!UnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/16/2013 22:44'!
initialize
	cambios := OrderedCollection new.
	cerrada := false.
	^self! !

!UnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/28/2013 15:29'!
registrarCambio: unCambio
	self estaCerrada ifTrue: [ UnidadDeTrabajoException  signal: self class noSePuedeRegistrarCambios]. 
	cambios add: unCambio.
	^self.! !

!UnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'SebastinGarbi 9/30/2013 01:21'!
todosLosCambios
	self subclassResponsibility.! !

!UnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'Maxii 10/18/2013 12:12'!
todosLosCambiosPropios
	^cambios.! !

UnidadDeTrabajo subclass: #UnidadDeTrabajoInicial
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!UnidadDeTrabajoInicial methodsFor: 'as yet unclassified' stamp: 'SebastinGarbi 9/30/2013 01:22'!
todosLosCambios 
	^cambios copy.! !

UnidadDeTrabajo subclass: #UnidadDeTrabajoReal
	instanceVariableNames: 'padre'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!UnidadDeTrabajoReal class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/16/2013 22:38'!
newWith: unaUnidadDeTrabajo
	^self new initializeWith: unaUnidadDeTrabajo.! !

!UnidadDeTrabajoReal methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/16/2013 22:39'!
initializeWith: unaUnidadDeTrabajo
	padre := unaUnidadDeTrabajo.
	^self.
	! !

!UnidadDeTrabajoReal methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 9/16/2013 22:53'!
padre
	^ padre! !

!UnidadDeTrabajoReal methodsFor: 'as yet unclassified' stamp: 'SebastinGarbi 9/30/2013 01:45'!
todosLosCambios 
	^self padre todosLosCambios addAll: cambios;yourself.! !

Object subclass: #VistaChanges
	instanceVariableNames: 'interfazWeb sistemaDeCambios modeloADibujar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

VistaChanges subclass: #VistaAgrupadoPorUnidadDeTrabajo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!VistaAgrupadoPorUnidadDeTrabajo class methodsFor: 'as yet unclassified' stamp: 'Maxii 12/6/2013 12:07'!
newWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloAgrupadoPorUnidadDeTrabajo andThisSistemaDeCambios: sistemaDeCambios
	^self new initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloAgrupadoPorUnidadDeTrabajo andThisSistemaDeCambios: sistemaDeCambios.! !

!VistaAgrupadoPorUnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 12:00'!
dibujarEn: html 
	self dibujarEncabezadoEn: html.
	self dibujarFormularioEn: html.
	self dibujarPorUnidadDeTrabajoEn: html.! !

!VistaAgrupadoPorUnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 21:48'!
dibujarPorUnidadDeTrabajoEn: html
	| nombreDeLaUnidad coleccionOrdenadaDeRegistros |
	
	html unorderedList: [ 
		self dibujarUnidadesCerradasEn: html.
		
		modeloADibujar usarUnidadActiva ifTrue: [ 
			nombreDeLaUnidad := 'UnidadActiva'.
			coleccionOrdenadaDeRegistros := self registrosOrdenadosCronologicamenteDeLaUnidadActiva.
				html listItem: [ 
					html anchor
							callback: [ interfazWeb armarAgregandoOQuitando: nombreDeLaUnidad printString ];
							with: nombreDeLaUnidad. 
					(modeloADibujar elementosAMostrar includes: nombreDeLaUnidad printString ) ifTrue: [ 
						self dibujarRegistros: coleccionOrdenadaDeRegistros en: html.
					 ]
				]
		 ]
	]
! !

!VistaAgrupadoPorUnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 21:53'!
dibujarUnidadesCerradasEn: html
	| nombreDeLaUnidadCerrada coleccionOrdenadaDeRegistrosDeLaUnidadCerrada |
	modeloADibujar unidadesCerradasAUsar do: [ :unId | 
			nombreDeLaUnidadCerrada := 'Unidad',unId printString.
			coleccionOrdenadaDeRegistrosDeLaUnidadCerrada := self registrosOrdenadosCronologicamenteDe: unId.
			html listItem: [ 
				html anchor
						callback: [ interfazWeb armarAgregandoOQuitando:  'Unidad',unId printString.];
						with: nombreDeLaUnidadCerrada. 
				(modeloADibujar elementosAMostrar includes:  'Unidad',unId printString) ifTrue: [ 
					self dibujarRegistros: coleccionOrdenadaDeRegistrosDeLaUnidadCerrada en: html.
					 ]
				]
		].! !

!VistaAgrupadoPorUnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 16:18'!
registrosOrdenadosCronologicamenteDe: unIdDeUnidadDeTrabajo 
	^(interfazWeb sistemaDeCambios todosLosCambiosDe: unIdDeUnidadDeTrabajo) sort: [ :registro1 :registro2 | registro1 fechaYHora <= registro2 fechaYHora ].
	! !

!VistaAgrupadoPorUnidadDeTrabajo methodsFor: 'as yet unclassified' stamp: 'Maxii 11/6/2013 16:13'!
registrosOrdenadosCronologicamenteDeLaUnidadActiva
	
	^interfazWeb sistemaDeCambios todosLosCambiosDeLaUnidadActiva sort: [ :registro1 :registro2 | registro1 fechaYHora <= registro2 fechaYHora ].
	! !

VistaChanges subclass: #VistaArbolDeCategoria
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!VistaArbolDeCategoria class methodsFor: 'as yet unclassified' stamp: 'Maxii 12/6/2013 12:06'!
newWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloAgrupadoPorUnidadDeTrabajo andThisSistemaDeCambios: sistemaDeCambios
	^self new initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloAgrupadoPorUnidadDeTrabajo andThisSistemaDeCambios: sistemaDeCambios.! !

!VistaArbolDeCategoria methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 15:46'!
dibujarDiccionarioDeCategoria: aDictionary en: html 
	aDictionary keysAndValuesDo: [ :aCategoria :aDiccionarioDeTipoChange |
		html unorderedList:  [ 
			html listItem: [
				html anchor
					callback: [interfazWeb armarAgregandoOQuitando: aCategoria ];
					with: aCategoria.
				(modeloADibujar elementosAMostrar includes: aCategoria) ifTrue: [
					self dibujarDiccionarioDeTipoChange: aDiccionarioDeTipoChange en: html.
					].
				].
			].
		].! !

!VistaArbolDeCategoria methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 19:21'!
dibujarDiccionarioDeTipoChange: aDictionary en: html 
	aDictionary keysAndValuesDo: [ :aCategoria :anOrderedCollectionDeChanges |
		html unorderedList:  [ 
			html listItem: [ 
				html anchor
					callback: [interfazWeb armarAgregandoOQuitando: aCategoria ];
					with: aCategoria.
				(modeloADibujar elementosAMostrar includes: aCategoria) ifTrue: [self dibujarRegistros: anOrderedCollectionDeChanges en: html.].
				].
			].
		].! !

!VistaArbolDeCategoria methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 19:26'!
dibujarEn: html 
	self dibujarEncabezadoEn: html.
	self dibujarFormularioEn: html.
	self dibujarModeloEn: html.
	! !

!VistaArbolDeCategoria methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 12:33'!
dibujarModeloEn: html 
	|dicc |
	
	dicc := interfazWeb cambiosCategorizadosPorElementoDeLasUnidadesSeleccionadas.
	self dibujarDiccionarioDeCategoria: dicc en: html.
! !

VistaChanges subclass: #VistaArbolDeEstadisticas
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!VistaArbolDeEstadisticas class methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 12:12'!
newWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios 
	^self new initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios.! !

!VistaArbolDeEstadisticas methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 12:14'!
dibujarEn: html 
	self dibujarEncabezadoEn: html.
	self dibujarFormularioEn: html.
	self dibujarModeloEn: html.! !

!VistaArbolDeEstadisticas methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 15:47'!
dibujarModeloEn: html
	|dicc |
	
	dicc := interfazWeb cambiosCategorizadosPorElementoDeLasUnidadesSeleccionadas.
	
	dicc keysAndValuesDo:  [ :categoria : claseChageOC |
		html render: categoria.
		html break.
		self dibujarSubParte: claseChageOC en: html.
		html horizontalRule.
	].! !

!VistaArbolDeEstadisticas methodsFor: 'as yet unclassified' stamp: 'Maxii 10/28/2013 00:26'!
dibujarSubParte: aDictionary en: html

	aDictionary keysAndValuesDo: [ :changeClassName :items |
		html render: changeClassName .
		html space.
		html space.
		html render: items size.
		html break.
	]	! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 20:10'!
dibujarCambio: unCambio en: html 
	unCambio accept: self return: html.
	"html preformatted: [ 
		unCambio dibujateSegun: self en: html.
	]"! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 19:58'!
dibujarDiccionarioAlineado: dic en: html
	
	| relacionador |
	relacionador := '='.
	html table: [
		html tableBody: [ 
			dic keysAndValuesDo: [ :objetoCambiado :valorDelObjeto |
				html tableRow: [ 
					html tableHeading:  objetoCambiado.
					html tableData: valorDelObjeto.
				 ].
			].
		].
	 ].
	 
	
"					html tableData: relacionador."! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 10/25/2013 18:16'!
dibujarEn: html 
	self subclassResponsibility.! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 11/3/2013 21:09'!
dibujarEncabezadoEn: html 
	html heading: 'CHANGES'.
	html anchor
			callback: [ 
				interfazWeb resetModelo.
				sistemaDeCambios idsDeUnidadesDeTrabajo do: [ :unId | interfazWeb agregarOQuitarUDT: unId ok: true ].
				interfazWeb agregarOQuitarUDTActiva: true.
				interfazWeb generarVistaCronologica ];
			with: 'Cambios Totales'.
	html space.
	html space.	
	html anchor
			callback: [ 
				interfazWeb resetModelo.
				interfazWeb generarVistaArbolPorUnidadDeTrabajo ];
			with: 'Cambios Totales Por Unidad'.
	html space.
	html space.
	html anchor
			callback: [
				interfazWeb resetModelo.
				interfazWeb generarVistaArbolPorCategoriaDeElemento ];
			with: 'Cambios Categorizados por elemento'.	
	html space.
	html space.
	html anchor
			callback: [ 
				interfazWeb resetModelo.
				interfazWeb generarVistaArbolDeEstadisticas ];
			with: 'Estadisticas Totales'.
	html space.
	html space.
	html anchor
			callback: [ 
				interfazWeb resetModelo.
				interfazWeb generarVistaHotSpot ];
			with: 'HotSpot'.
	html space.
	html space.
	html anchor
			callback: [ 
				interfazWeb resetModelo.
				interfazWeb generarVistaTDDVsTesting ];
			with: 'TDD VS Testing'.
	html horizontalRule.! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 15:42'!
dibujarFormularioEn: html 
	html form: [
		sistemaDeCambios idsDeUnidadesDeTrabajo asOrderedCollection do: [ :id |
			html div:[
				html text: 'Unidad ',id printString.
				html checkbox
					value: (modeloADibujar unidadesCerradasAUsar includes: id);
					callback: [ :value | interfazWeb agregarOQuitarUDT: id ok: value ].
			].
		].
		html div:[
			html text: 'Unidad Activa'.
			html checkbox
				value: modeloADibujar usarUnidadActiva;
				callback: [ :value | interfazWeb agregarOQuitarUDTActiva: value ].
		].
		html div: [html submitButton: 'Enviar'.]. 	
		].
	html horizontalRule.! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 20:56'!
dibujarLista: coleccionOrdenadaDeRegistros en: html 
	html unorderedList: [
		coleccionOrdenadaDeRegistros do: [ :unRegistro |
			html listItem: [ 
				self dibujarDiccionarioAlineado: unRegistro en: html.
"				self dibujarRegistro: unRegistro en: html."
				html break.
				html text: '---------------------------------------------------'
			].
		].
	].! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 22:01'!
dibujarRegistro: unRegistroDeCambio en: html 
	html table: [ 
		html tableBody: [
			html tableRow: [
				html tableHeading: 'Autor'.
				html tableData: unRegistroDeCambio autor.
			].
			html tableRow: [ 
				html tableHeading: 'Fecha y hora'.
				html tableData: unRegistroDeCambio fechaYHora.
			].
			html tableRow: [ 
				html tableHeading: 'Tipo'.
				html tableData: unRegistroDeCambio cambio class evento.
			].
				self dibujarCambio: unRegistroDeCambio cambio en: html
		].
	].! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/2/2013 21:54'!
dibujarRegistros: coleccionOrdenadaDeRegistros en: html
		"| listaDeRegistrosParaDibujar |
		listaDeRegistrosParaDibujar := ListaDeRegistrosParaDibujar para: coleccionOrdenadaDeRegistros.
		self dibujarLista: listaDeRegistrosParaDibujar obtener en: html."
		html unorderedList: [ 
			coleccionOrdenadaDeRegistros do: [ :unRegistro |
				html listItem: [ 
					self dibujarRegistro: unRegistro en: html.
					html break.
					html text: '---------------------------------------------------'
				].
			].
		].! !

!VistaChanges methodsFor: 'htmlHelper' stamp: 'SebastianGarbi 11/2/2013 22:11'!
html: html categoryCreated_Removed: aClassCategoryCreatedChange 
	self html: html tableRowKey: 'categoryName' value: aClassCategoryCreatedChange categoryName.! !

!VistaChanges methodsFor: 'htmlHelper' stamp: 'SebastianGarbi 11/2/2013 22:43'!
html: html categoryReorganized: aMethodCategoyReorganizedChange
	self html: html tableRowKey: 'classAffected' value: aMethodCategoyReorganizedChange classAffected.
	self html: html tableRowKey: 'arrayDeCategorias' value: aMethodCategoyReorganizedChange arrayDeCategorias.! !

!VistaChanges methodsFor: 'htmlHelper' stamp: 'SebastianGarbi 11/2/2013 22:49'!
html: html methodChanged: aClassMethodChangedChange 
	self html: html tableRowKey: 'methodName' value: aClassMethodChangedChange methodName.
	self html: html tableRowKey: 'classAffected' value: aClassMethodChangedChange classAffected.
	self html: html tableRowPreformatedKey: 'oldSourceCode' value: aClassMethodChangedChange oldSourceCode.
	self html: html tableRowPreformatedKey: 'newSourceCode' value: aClassMethodChangedChange newSourceCode.
	! !

!VistaChanges methodsFor: 'htmlHelper' stamp: 'SebastianGarbi 11/2/2013 22:26'!
html: html methodCreated_Removed: anInstanceMethodRemovedChange
	self html: html tableRowKey: 'methodName' value: anInstanceMethodRemovedChange methodName.
	self html: html tableRowKey: 'methodCategory' value: anInstanceMethodRemovedChange methodCategory.
	self html: html tableRowPreformatedKey: 'sourceCode' value: anInstanceMethodRemovedChange sourceCode.
	self html: html tableRowKey: 'classAffected' value: anInstanceMethodRemovedChange classAffected! !

!VistaChanges methodsFor: 'htmlHelper' stamp: 'SebastianGarbi 11/2/2013 22:54'!
html: html methodRecategorized: aMethodRecategorizedChange 
	self html: html tableRowKey: 'methodName' value: aMethodRecategorizedChange methodName.
	self html: html tableRowKey: 'classAffected' value: aMethodRecategorizedChange classAffected.
	self html: html  tableRowKey:  'oldMethodCategory' value: aMethodRecategorizedChange oldMethodCategory.
	self html: html  tableRowKey:  'newMethodCategory' value: aMethodRecategorizedChange newMethodCategory.
! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 12:55'!
html: html poolDictionary: aPoolDictionaryCreatedChange 

	self html: html tableRowKey:  'classAffected' value: aPoolDictionaryCreatedChange classAffected.
	self html: html tableRowKey:  'poolDictionary' value: aPoolDictionaryCreatedChange poolDictionaryName.! !

!VistaChanges methodsFor: 'htmlHelper' stamp: 'SebastianGarbi 11/2/2013 22:20'!
html: html tableRowKey: aKey value: aValue
	html tableRow: [ 
		html tableHeading: aKey.
		html tableData: aValue.
	 ].
	! !

!VistaChanges methodsFor: 'htmlHelper' stamp: 'SebastianGarbi 11/2/2013 22:25'!
html: html tableRowPreformatedKey: aKey value: aValue
	self html: html tableRowKey: aKey value: [ html preformatted: [ html text: aValue] ].! !

!VistaChanges methodsFor: 'htmlHelper' stamp: 'SebastianGarbi 11/2/2013 22:58'!
html: html variable: anInstanceVariableCreatedChange 
	self html: html tableRowKey:  'classAffected' value: anInstanceVariableCreatedChange classAffected.
	self html: html tableRowKey:  'variableName' value: anInstanceVariableCreatedChange variableName.! !

!VistaChanges methodsFor: 'initialize-release' stamp: 'Maxii 10/29/2013 18:48'!
initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios 
	interfazWeb := anInterfazDeEntradaWeb.
	sistemaDeCambios := aSistemaDeCambios.
	modeloADibujar := aModeloADibujar.! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 10/30/2013 18:31'!
quitarOPoner: aByteString en: anOrderedCollection 
	anOrderedCollection remove: aByteString ifAbsent: [ anOrderedCollection add: aByteString ].
	^anOrderedCollection.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:10'!
visitClassCategoryCreatedChange: aClassCategoryCreatedChange with: html
	self html: html categoryCreated_Removed: aClassCategoryCreatedChange.

	! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:27'!
visitClassCategoryRemovedChange: aClassCategoryRemovedChange with: html
	self html: html categoryCreated_Removed: aClassCategoryRemovedChange.

	! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 23:09'!
visitClassCategoryRenamedChange: aClassCategoryRenamedChange with: html
	self html: html tableRowKey: 'oldCategoryName' value: aClassCategoryRenamedChange oldCategoryName.
	self html: html tableRowKey: 'newCategoryName' value: aClassCategoryRenamedChange newCategoryName.

	! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:31'!
visitClassCreatedChange: aClassCreatedChange with: html
	self html: html tableRowKey: 'classCreated' value: aClassCreatedChange classCreated.
	self html: html tableRowKey: 'classCategory' value: aClassCreatedChange classCategory.
	self html: html tableRowKey: 'superclass' value: aClassCreatedChange superclass.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 23:01'!
visitClassInstanceVariableCreatedChange: aClassInstanceVariableCreatedChange with: html
	self html: html variable: aClassInstanceVariableCreatedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 23:00'!
visitClassInstanceVariableRemovedChange: aClassInstanceVariableRemovedChange with: html
	self html: html variable: aClassInstanceVariableRemovedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:43'!
visitClassMethodCategoyReorganizedChange: aClassMethodCategoyReorganizedChange with: html
	self html: html categoryReorganized: aClassMethodCategoyReorganizedChange.
	! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:45'!
visitClassMethodChangedChange: aClassMethodChangedChange with: html
	self html: html methodChanged: aClassMethodChangedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:09'!
visitClassMethodCreatedChange: aClassMethodCreatedChange with: html
	self html: html methodCreated_Removed: aClassMethodCreatedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:50'!
visitClassMethodRecategorizedChange: aClassMethodRecategorizedChange with: html
	self html: html methodRecategorized: aClassMethodRecategorizedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:50'!
visitClassMethodRemovedChange: aClassMethodRemovedChange with: html
	self html: html methodCreated_Removed: aClassMethodRemovedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 23:04'!
visitClassRecategorizedChange: aClassRecategorizedChange with: html
	self html: html tableRowKey: 'classRecategorized' value: aClassRecategorizedChange classRecategorized.
	self html: html tableRowKey: 'oldCategory' value: aClassRecategorizedChange oldCategory.
	self html: html tableRowKey: 'newCategory' value: aClassRecategorizedChange newCategory.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:33'!
visitClassRemovedChange: aClassRemovedChange with: html
	self html: html tableRowKey: 'classRemoved' value: aClassRemovedChange classRemoved.
	self html: html tableRowKey: 'classCategory' value: aClassRemovedChange classCategory.	
! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:59'!
visitClassVariableCreatedChange: aClassVariableCreatedChange with: html
	self html: html variable: aClassVariableCreatedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 23:00'!
visitClassVariableRemovedChange: aClassVariableRemovedChange with: html
	self html: html variable: aClassVariableRemovedChange.
	! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:44'!
visitInstanceMethodCategoyReorganizedChange: anInstanceMethodCategoyReorganizedChange with: html
	self html: html categoryReorganized: anInstanceMethodCategoyReorganizedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:55'!
visitInstanceMethodChangedChange: anInstanceMethodChangedChange with: html
	self html: html methodChanged: anInstanceMethodChangedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:56'!
visitInstanceMethodCreatedChange: anInstanceMethodCreatedChange with: html
	self html: html methodCreated_Removed: anInstanceMethodCreatedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:56'!
visitInstanceMethodRecategorizedChange: anInstanceMethodRecategorizedChange with: html
	self html: html methodRecategorized: anInstanceMethodRecategorizedChange .! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:09'!
visitInstanceMethodRemovedChange: anInstanceMethodRemovedChange with: html
	self html: html methodCreated_Removed: anInstanceMethodRemovedChange! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:57'!
visitInstanceVariableCreatedChange: anInstanceVariableCreatedChange with: html
	self html: html variable: anInstanceVariableCreatedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 22:59'!
visitInstanceVariableRemovedChange: anInstanceVariableRemovedChange with: html
	self html: html variable: anInstanceVariableRemovedChange ! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 12:53'!
visitPoolDictionaryCreatedChange: aPoolDictionaryCreatedChange with: html 
	self html: html poolDictionary: aPoolDictionaryCreatedChange.! !

!VistaChanges methodsFor: 'as yet unclassified' stamp: 'Maxii 11/11/2013 13:00'!
visitPoolDictionaryRemovedChange: aPoolDictionaryRemovedChange with: html 
	
	self html: html poolDictionary: aPoolDictionaryRemovedChange.! !

!VistaChanges methodsFor: 'visitor' stamp: 'SebastianGarbi 11/2/2013 23:02'!
visitSuperclassChangedChange: aSuperclassChangedChange with: html 
	self html: html tableRowKey: 'classAffected' value: aSuperclassChangedChange classAffected.
	self html: html tableRowKey: 'oldSuperclass' value: aSuperclassChangedChange oldSuperclass.
	self html: html tableRowKey: 'newSuperclass' value: aSuperclassChangedChange newSuperclass.! !

VistaChanges subclass: #VistaCronologica
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!VistaCronologica class methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 20:36'!
newWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModelo: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios 
	
	^self new initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios.! !

!VistaCronologica methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 20:38'!
dibujarEn: html 
	self dibujarEncabezadoEn: html.
	self dibujarTodosLosRegistrosEn: html.
	"coleccionDeRegistros do: [ :unRegistro | 		self dibujarRegistro: unRegistro en: html.
													self dibujarSeparadorEn: html ]."! !

!VistaCronologica methodsFor: 'as yet unclassified' stamp: 'Maxii 11/1/2013 16:16'!
dibujarTodosLosRegistrosEn: html 
	
	| todosLosRegistrosDelGrupo unaCollecionDeIdsDeUnidadesDeTrabajo |
	
	todosLosRegistrosDelGrupo := OrderedCollection new.
	
	unaCollecionDeIdsDeUnidadesDeTrabajo := modeloADibujar unidadesCerradasAUsar.
	unaCollecionDeIdsDeUnidadesDeTrabajo do: [ :unID | todosLosRegistrosDelGrupo addAll: (interfazWeb sistemaDeCambios todosLosCambiosDe: unID ) ].
	
	modeloADibujar usarUnidadActiva ifTrue: [ todosLosRegistrosDelGrupo addAll: (interfazWeb sistemaDeCambios todosLosCambiosDeLaUnidadActiva) ].
	
	todosLosRegistrosDelGrupo sort: [ :registro1 :registro2 | registro1 fechaYHora <= registro2 fechaYHora ].
	
	self dibujarRegistros: todosLosRegistrosDelGrupo en: html.! !

VistaChanges subclass: #VistaDePresentacion
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!VistaDePresentacion class methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 18:44'!
newWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModelo: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios 
	
	^self new initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios.! !

!VistaDePresentacion methodsFor: 'as yet unclassified' stamp: 'Maxii 10/26/2013 17:24'!
dibujarAccionesEn: html 
	! !

!VistaDePresentacion methodsFor: 'as yet unclassified' stamp: 'Maxii 10/26/2013 12:33'!
dibujarEn: html 
	self dibujarEncabezadoEn: html.
	self dibujarAccionesEn: html.! !

!VistaDePresentacion methodsFor: 'as yet unclassified' stamp: 'Maxii 10/29/2013 18:47'!
initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios 
	super initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios.! !

VistaChanges subclass: #VistaHotSpot
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!VistaHotSpot class methodsFor: 'as yet unclassified' stamp: 'Maxii 11/3/2013 19:51'!
newWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios 
	^self new initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios.! !

!VistaHotSpot methodsFor: 'as yet unclassified' stamp: 'Maxii 11/3/2013 20:01'!
calcularCantidadDeCambiosTotales: aDictionary 
	| total |
	total := 0.
	aDictionary keysAndValuesDo: [ :tipoDeCambio :coleccionDeCambios |
		total := total + (coleccionDeCambios size) ].
	^total.! !

!VistaHotSpot methodsFor: 'as yet unclassified' stamp: 'Maxii 11/3/2013 19:31'!
dibujarEn: html 
	self dibujarEncabezadoEn: html.
	self dibujarFormularioEn: html.
	self dibujarModeloEn: html.! !

!VistaHotSpot methodsFor: 'as yet unclassified' stamp: 'Maxii 11/3/2013 21:35'!
dibujarModeloEn: html
	| dicc diccDeCambiosPorElementosTotales |
	
	dicc := interfazWeb cambiosCategorizadosPorElementoDeLasUnidadesSeleccionadas.
	diccDeCambiosPorElementosTotales := Dictionary new.
	dicc keysAndValuesDo:  [ :categoria : claseChageOC | 
		diccDeCambiosPorElementosTotales at: categoria put: (self calcularCantidadDeCambiosTotales: claseChageOC) ].
		
	diccDeCambiosPorElementosTotales keysAndValuesDo: [ :categoria :cantidadDeCambios | 
		html text: categoria.
		html space.
		html text: cantidadDeCambios.
		html break.
		html image form: ( LineMorph from: 0@0 to: cantidadDeCambios@0 color: Color green width: 10 ).								
		html break.
		].
! !

!VistaHotSpot methodsFor: 'as yet unclassified' stamp: 'Maxii 11/3/2013 19:32'!
dibujarSubParte: aDictionary en: html

	aDictionary keysAndValuesDo: [ :changeClassName :items |
		html render: changeClassName .
		html space.
		html space.
		html render: items size.
		html break.
	]	! !

VistaChanges subclass: #VistaTddVsTesting
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-TP-Changes'!

!VistaTddVsTesting class methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:45'!
newWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios 
	^self new initializeWithThisInterfazWeb: anInterfazDeEntradaWeb andThisModel: aModeloADibujar andThisSistemaDeCambios: aSistemaDeCambios.! !

!VistaTddVsTesting methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:45'!
dibujarEn: html 
	self dibujarEncabezadoEn: html.
	self dibujarModeloEn: html.
	! !

!VistaTddVsTesting methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 20:47'!
dibujarModeloEn: html 
	|dicc |
	dicc := interfazWeb cambiosParaTddVsTesting.
	self dibujarTddVsTesting: dicc en: html.
! !

!VistaTddVsTesting methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 21:05'!
dibujarTddVsTesting: aDictionary en: html 
	html unorderedList: [
		self html: html listitemPrimerNivelDe: 'TDD' con: aDictionary .
		self html: html listitemPrimerNivelDe: 'Testing' con: aDictionary.
	].! !

!VistaTddVsTesting methodsFor: 'as yet unclassified' stamp: 'SebastianGarbi 11/3/2013 21:05'!
html: html listitemPrimerNivelDe: aByteString con: aDictionary 
	html listItem: [ 
		html text: aByteString;
			break;
			unorderedList: [ 
				(aDictionary at: aByteString)
					do: [ :unParDeRegistros |
						html listItem: [ 
							html text: 'Mtodo';
								table: [self dibujarRegistro: (unParDeRegistros at: 'metodo') en: html.]
						 ].
						html listItem: [ 
							html text: 'Test';
								table: [self dibujarRegistro: (unParDeRegistros at: 'test') en: html.]
						 ].
					]
			]
	].! !
